@@ -4,18 +4,16 @@ import warnings
 import numpy as np
 from numpy.testing import assert_almost_equal
 
-from openmdao.api import Problem, Group, IndepVarComp, ExecComp, \
-    EQConstraintComp, ScipyOptimizeDriver
-
+import openmdao.api as om
 from openmdao.test_suite.components.sellar_feature import SellarIDF
-
 from openmdao.utils.assert_utils import assert_rel_error, assert_check_partials
 
+
 class TestEQConstraintComp(unittest.TestCase):
 
     def test_sellar_idf(self):
-        prob = Problem(SellarIDF())
-        prob.driver = ScipyOptimizeDriver(optimizer='SLSQP', disp=False)
+        prob = om.Problem(SellarIDF())
+        prob.driver = om.ScipyOptimizeDriver(optimizer='SLSQP', disp=False)
         prob.setup()
 
         # check derivatives
@@ -49,14 +47,14 @@ class TestEQConstraintComp(unittest.TestCase):
         assert_almost_equal(prob['equal.y2'], 0.0)
 
     def test_create_on_init(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
         # find intersection of two non-parallel lines
-        model.add_subsystem('indep', IndepVarComp('x', val=0.))
-        model.add_subsystem('f', ExecComp('y=3*x-3', x=0.))
-        model.add_subsystem('g', ExecComp('y=2.3*x+4', x=0.))
-        model.add_subsystem('equal', EQConstraintComp('y', val=11.))
+        model.add_subsystem('indep', om.IndepVarComp('x', val=0.))
+        model.add_subsystem('f', om.ExecComp('y=3*x-3', x=0.))
+        model.add_subsystem('g', om.ExecComp('y=2.3*x+4', x=0.))
+        model.add_subsystem('equal', om.EQConstraintComp('y', val=11.))
 
         model.connect('indep.x', 'f.x')
         model.connect('indep.x', 'g.x')
@@ -79,7 +77,7 @@ class TestEQConstraintComp(unittest.TestCase):
         model.add_constraint('equal.y', equals=0.)
         prob.setup(mode='fwd')
 
-        prob.driver = ScipyOptimizeDriver(disp=False)
+        prob.driver = om.ScipyOptimizeDriver(disp=False)
 
         prob.run_driver()
 
@@ -96,14 +94,14 @@ class TestEQConstraintComp(unittest.TestCase):
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_create_on_init_add_constraint(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
         # find intersection of two non-parallel lines
-        model.add_subsystem('indep', IndepVarComp('x', val=0.))
-        model.add_subsystem('f', ExecComp('y=3*x-3', x=0.))
-        model.add_subsystem('g', ExecComp('y=2.3*x+4', x=0.))
-        model.add_subsystem('equal', EQConstraintComp('y', add_constraint=True))
+        model.add_subsystem('indep', om.IndepVarComp('x', val=0.))
+        model.add_subsystem('f', om.ExecComp('y=3*x-3', x=0.))
+        model.add_subsystem('g', om.ExecComp('y=2.3*x+4', x=0.))
+        model.add_subsystem('equal', om.EQConstraintComp('y', add_constraint=True))
 
         model.connect('indep.x', 'f.x')
         model.connect('indep.x', 'g.x')
@@ -119,7 +117,7 @@ class TestEQConstraintComp(unittest.TestCase):
         # verify that the constraint has been added as requested
         self.assertTrue('equal.y' in model.get_constraints())
 
-        prob.driver = ScipyOptimizeDriver(disp=False)
+        prob.driver = om.ScipyOptimizeDriver(disp=False)
 
         prob.run_driver()
 
@@ -136,15 +134,15 @@ class TestEQConstraintComp(unittest.TestCase):
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_create_on_init_add_constraint_no_normalization(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
         # find intersection of two non-parallel lines
-        model.add_subsystem('indep', IndepVarComp('x', val=-2.0))
-        model.add_subsystem('f', ExecComp('y=3*x-3', x=0.))
-        model.add_subsystem('g', ExecComp('y=2.3*x+4', x=0.))
-        model.add_subsystem('equal', EQConstraintComp('y', add_constraint=True, normalize=False,
-                                                      ref0=0, ref=100.0))
+        model.add_subsystem('indep', om.IndepVarComp('x', val=-2.0))
+        model.add_subsystem('f', om.ExecComp('y=3*x-3', x=0.))
+        model.add_subsystem('g', om.ExecComp('y=2.3*x+4', x=0.))
+        model.add_subsystem('equal', om.EQConstraintComp('y', add_constraint=True, normalize=False,
+                                                         ref0=0, ref=100.0))
 
         model.connect('indep.x', 'f.x')
         model.connect('indep.x', 'g.x')
@@ -167,7 +165,7 @@ class TestEQConstraintComp(unittest.TestCase):
         diff = lhs - rhs
         assert_rel_error(self, prob['equal.y'], diff)
 
-        prob.driver = ScipyOptimizeDriver(disp=False)
+        prob.driver = om.ScipyOptimizeDriver(disp=False)
 
         prob.run_driver()
 
@@ -184,17 +182,17 @@ class TestEQConstraintComp(unittest.TestCase):
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_vectorized(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
         n = 100
 
         # find intersection of two non-parallel lines, vectorized
-        model.add_subsystem('indep', IndepVarComp('x', val=np.ones(n)))
-        model.add_subsystem('f', ExecComp('y=3*x-3', x=np.ones(n), y=np.ones(n)))
-        model.add_subsystem('g', ExecComp('y=2.3*x+4', x=np.ones(n), y=np.ones(n)))
-        model.add_subsystem('equal', EQConstraintComp('y', val=np.ones(n), add_constraint=True))
-        model.add_subsystem('obj_cmp', ExecComp('obj=sum(y)', y=np.zeros(n)))
+        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(n)))
+        model.add_subsystem('f', om.ExecComp('y=3*x-3', x=np.ones(n), y=np.ones(n)))
+        model.add_subsystem('g', om.ExecComp('y=2.3*x+4', x=np.ones(n), y=np.ones(n)))
+        model.add_subsystem('equal', om.EQConstraintComp('y', val=np.ones(n), add_constraint=True))
+        model.add_subsystem('obj_cmp', om.ExecComp('obj=sum(y)', y=np.zeros(n)))
 
         model.connect('indep.x', 'f.x')
         model.connect('indep.x', 'g.x')
@@ -207,7 +205,7 @@ class TestEQConstraintComp(unittest.TestCase):
 
         prob.setup(mode='fwd')
 
-        prob.driver = ScipyOptimizeDriver(disp=False)
+        prob.driver = om.ScipyOptimizeDriver(disp=False)
 
         prob.run_driver()
 
@@ -224,18 +222,18 @@ class TestEQConstraintComp(unittest.TestCase):
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_vectorized_no_normalization(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
         n = 100
 
         # find intersection of two non-parallel lines, vectorized
-        model.add_subsystem('indep', IndepVarComp('x', val=-2.0*np.ones(n)))
-        model.add_subsystem('f', ExecComp('y=3*x-3', x=np.ones(n), y=np.ones(n)))
-        model.add_subsystem('g', ExecComp('y=2.3*x+4', x=np.ones(n), y=np.ones(n)))
-        model.add_subsystem('equal', EQConstraintComp('y', val=np.ones(n), add_constraint=True,
-                                                      normalize=False))
-        model.add_subsystem('obj_cmp', ExecComp('obj=sum(y)', y=np.zeros(n)))
+        model.add_subsystem('indep', om.IndepVarComp('x', val=-2.0*np.ones(n)))
+        model.add_subsystem('f', om.ExecComp('y=3*x-3', x=np.ones(n), y=np.ones(n)))
+        model.add_subsystem('g', om.ExecComp('y=2.3*x+4', x=np.ones(n), y=np.ones(n)))
+        model.add_subsystem('equal', om.EQConstraintComp('y', val=np.ones(n), add_constraint=True,
+                                                         normalize=False))
+        model.add_subsystem('obj_cmp', om.ExecComp('obj=sum(y)', y=np.zeros(n)))
 
         model.connect('indep.x', 'f.x')
         model.connect('indep.x', 'g.x')
@@ -248,7 +246,7 @@ class TestEQConstraintComp(unittest.TestCase):
 
         prob.setup(mode='fwd')
 
-        prob.driver = ScipyOptimizeDriver(disp=False)
+        prob.driver = om.ScipyOptimizeDriver(disp=False)
 
         # verify that the output is not being normalized
         prob.run_model()
@@ -272,14 +270,14 @@ class TestEQConstraintComp(unittest.TestCase):
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_scalar_with_mult(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
         # find where 2*x == x^2
-        model.add_subsystem('indep', IndepVarComp('x', val=1.))
-        model.add_subsystem('multx', IndepVarComp('m', val=2.))
-        model.add_subsystem('f', ExecComp('y=x**2', x=1.))
-        model.add_subsystem('equal', EQConstraintComp('y', use_mult=True))
+        model.add_subsystem('indep', om.IndepVarComp('x', val=1.))
+        model.add_subsystem('multx', om.IndepVarComp('m', val=2.))
+        model.add_subsystem('f', om.ExecComp('y=x**2', x=1.))
+        model.add_subsystem('equal', om.EQConstraintComp('y', use_mult=True))
 
         model.connect('indep.x', 'f.x')
 
@@ -292,7 +290,7 @@ class TestEQConstraintComp(unittest.TestCase):
         model.add_objective('f.y')
 
         prob.setup(mode='fwd')
-        prob.driver = ScipyOptimizeDriver(disp=False)
+        prob.driver = om.ScipyOptimizeDriver(disp=False)
         prob.run_driver()
 
         assert_rel_error(self, prob['equal.y'], 0., 1e-6)
@@ -306,14 +304,14 @@ class TestEQConstraintComp(unittest.TestCase):
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_complex_step(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
         # find where 2*x == x^2
-        model.add_subsystem('indep', IndepVarComp('x', val=1.))
-        model.add_subsystem('multx', IndepVarComp('m', val=2.))
-        model.add_subsystem('f', ExecComp('y=x**2', x=1.))
-        model.add_subsystem('equal', EQConstraintComp('y', use_mult=True))
+        model.add_subsystem('indep', om.IndepVarComp('x', val=1.))
+        model.add_subsystem('multx', om.IndepVarComp('m', val=2.))
+        model.add_subsystem('f', om.ExecComp('y=x**2', x=1.))
+        model.add_subsystem('equal', om.EQConstraintComp('y', use_mult=True))
 
         model.connect('indep.x', 'f.x')
 
@@ -326,7 +324,7 @@ class TestEQConstraintComp(unittest.TestCase):
         model.add_objective('f.y')
 
         prob.setup(mode='fwd', force_alloc_complex=True)
-        prob.driver = ScipyOptimizeDriver(disp=False)
+        prob.driver = om.ScipyOptimizeDriver(disp=False)
         prob.run_driver()
 
         with warnings.catch_warnings():
@@ -336,18 +334,18 @@ class TestEQConstraintComp(unittest.TestCase):
         assert_check_partials(cpd, atol=1e-10, rtol=1e-10)
 
     def test_vectorized_with_mult(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
         n = 100
 
         # find where 2*x == x^2, vectorized
-        model.add_subsystem('indep', IndepVarComp('x', val=np.ones(n)))
-        model.add_subsystem('multx', IndepVarComp('m', val=np.ones(n)*2.))
-        model.add_subsystem('f', ExecComp('y=x**2', x=np.ones(n), y=np.ones(n)))
-        model.add_subsystem('equal', EQConstraintComp('y', val=np.ones(n),
+        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(n)))
+        model.add_subsystem('multx', om.IndepVarComp('m', val=np.ones(n)*2.))
+        model.add_subsystem('f', om.ExecComp('y=x**2', x=np.ones(n), y=np.ones(n)))
+        model.add_subsystem('equal', om.EQConstraintComp('y', val=np.ones(n),
                             use_mult=True, add_constraint=True))
-        model.add_subsystem('obj_cmp', ExecComp('obj=sum(y)', y=np.zeros(n)))
+        model.add_subsystem('obj_cmp', om.ExecComp('obj=sum(y)', y=np.zeros(n)))
 
         model.connect('indep.x', 'f.x')
 
@@ -360,7 +358,7 @@ class TestEQConstraintComp(unittest.TestCase):
         model.add_objective('obj_cmp.obj')
 
         prob.setup(mode='fwd')
-        prob.driver = ScipyOptimizeDriver(disp=False)
+        prob.driver = om.ScipyOptimizeDriver(disp=False)
         prob.run_driver()
 
         assert_rel_error(self, prob['equal.y'], np.zeros(n), 1e-6)
@@ -374,17 +372,17 @@ class TestEQConstraintComp(unittest.TestCase):
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_vectorized_with_default_mult(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
         n = 100
 
         # find where 2*x == x^2, vectorized
-        model.add_subsystem('indep', IndepVarComp('x', val=np.ones(n)))
-        model.add_subsystem('f', ExecComp('y=x**2', x=np.ones(n), y=np.ones(n)))
-        model.add_subsystem('equal', EQConstraintComp('y', val=np.ones(n),
+        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(n)))
+        model.add_subsystem('f', om.ExecComp('y=x**2', x=np.ones(n), y=np.ones(n)))
+        model.add_subsystem('equal', om.EQConstraintComp('y', val=np.ones(n),
                             use_mult=True, mult_val=2., add_constraint=True))
-        model.add_subsystem('obj_cmp', ExecComp('obj=sum(y)', y=np.zeros(n)))
+        model.add_subsystem('obj_cmp', om.ExecComp('obj=sum(y)', y=np.zeros(n)))
 
         model.connect('indep.x', 'f.x')
 
@@ -396,7 +394,7 @@ class TestEQConstraintComp(unittest.TestCase):
         model.add_objective('obj_cmp.obj')
 
         prob.setup(mode='fwd')
-        prob.driver = ScipyOptimizeDriver(disp=False)
+        prob.driver = om.ScipyOptimizeDriver(disp=False)
         prob.run_driver()
 
         assert_rel_error(self, prob['equal.y'], np.zeros(n), 1e-6)
@@ -410,13 +408,13 @@ class TestEQConstraintComp(unittest.TestCase):
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_rhs_val(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
         # find where x^2 == 4
-        model.add_subsystem('indep', IndepVarComp('x', val=1.))
-        model.add_subsystem('f', ExecComp('y=x**2', x=1.))
-        model.add_subsystem('equal', EQConstraintComp('y', rhs_val=4.))
+        model.add_subsystem('indep', om.IndepVarComp('x', val=1.))
+        model.add_subsystem('f', om.ExecComp('y=x**2', x=1.))
+        model.add_subsystem('equal', om.EQConstraintComp('y', rhs_val=4.))
 
         model.connect('indep.x', 'f.x')
         model.connect('f.y', 'equal.lhs:y')
@@ -426,7 +424,7 @@ class TestEQConstraintComp(unittest.TestCase):
         model.add_objective('f.y')
 
         prob.setup(mode='fwd')
-        prob.driver = ScipyOptimizeDriver(disp=False)
+        prob.driver = om.ScipyOptimizeDriver(disp=False)
         prob.run_driver()
 
         assert_rel_error(self, prob['equal.y'], 0., 1e-6)
@@ -441,17 +439,17 @@ class TestEQConstraintComp(unittest.TestCase):
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_vectorized_rhs_val(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
         n = 100
 
         # find where x^2 == 4, vectorized
-        model.add_subsystem('indep', IndepVarComp('x', val=np.ones(n)))
-        model.add_subsystem('f', ExecComp('y=x**2', x=np.ones(n), y=np.ones(n)))
-        model.add_subsystem('equal', EQConstraintComp('y', val=np.ones(n),
+        model.add_subsystem('indep', om.IndepVarComp('x', val=np.ones(n)))
+        model.add_subsystem('f', om.ExecComp('y=x**2', x=np.ones(n), y=np.ones(n)))
+        model.add_subsystem('equal', om.EQConstraintComp('y', val=np.ones(n),
                             rhs_val=np.ones(n)*4., use_mult=True, mult_val=2.))
-        model.add_subsystem('obj_cmp', ExecComp('obj=sum(y)', y=np.zeros(n)))
+        model.add_subsystem('obj_cmp', om.ExecComp('obj=sum(y)', y=np.zeros(n)))
 
         model.connect('indep.x', 'f.x')
 
@@ -463,7 +461,7 @@ class TestEQConstraintComp(unittest.TestCase):
         model.add_objective('obj_cmp.obj')
 
         prob.setup(mode='fwd')
-        prob.driver = ScipyOptimizeDriver(disp=False)
+        prob.driver = om.ScipyOptimizeDriver(disp=False)
         prob.run_driver()
 
         assert_rel_error(self, prob['equal.y'], np.zeros(n), 1e-6)
@@ -475,16 +473,16 @@ class TestEQConstraintComp(unittest.TestCase):
             assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
 
     def test_renamed_vars(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
         # find intersection of two non-parallel lines, fx_y and gx_y
-        equal = EQConstraintComp('y', lhs_name='fx_y', rhs_name='gx_y',
-                                        add_constraint=True)
+        equal = om.EQConstraintComp('y', lhs_name='fx_y', rhs_name='gx_y',
+                                    add_constraint=True)
 
-        model.add_subsystem('indep', IndepVarComp('x', val=0.))
-        model.add_subsystem('f', ExecComp('y=3*x-3', x=0.))
-        model.add_subsystem('g', ExecComp('y=2.3*x+4', x=0.))
+        model.add_subsystem('indep', om.IndepVarComp('x', val=0.))
+        model.add_subsystem('f', om.ExecComp('y=3*x-3', x=0.))
+        model.add_subsystem('g', om.ExecComp('y=2.3*x+4', x=0.))
         model.add_subsystem('equal', equal)
 
         model.connect('indep.x', 'f.x')
@@ -497,7 +495,7 @@ class TestEQConstraintComp(unittest.TestCase):
         model.add_objective('f.y')
 
         prob.setup(mode='fwd')
-        prob.driver = ScipyOptimizeDriver(disp=False)
+        prob.driver = om.ScipyOptimizeDriver(disp=False)
         prob.run_driver()
 
         assert_almost_equal(prob['equal.y'], 0.)
@@ -516,11 +514,11 @@ class TestEQConstraintComp(unittest.TestCase):
 class TestFeatureEQConstraintComp(unittest.TestCase):
 
     def test_feature_sellar_idf(self):
-        from openmdao.api import Problem, ScipyOptimizeDriver
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar_feature import SellarIDF
 
-        prob = Problem(model=SellarIDF())
-        prob.driver = ScipyOptimizeDriver(optimizer='SLSQP', disp=True)
+        prob = om.Problem(model=SellarIDF())
+        prob.driver = om.ScipyOptimizeDriver(optimizer='SLSQP', disp=True)
         prob.setup()
         prob.run_driver()
 
