@@ -162,7 +162,14 @@ class Driver(object):
         self.iter_count = 0
         self.cite = ""
 
-        self._coloring_info = {'coloring': None, 'show_summary': True, 'show_sparsity': False}
+        self._coloring_info = {
+            'coloring': None,
+            'show_summary': True,
+            'show_sparsity': False,
+            'tol': 1e-15,
+            'orders': 20,
+            'num_full_jacs': 3,
+        }
         self._total_jac_sparsity = None
         self._res_jacs = {}
         self._total_jac = None
@@ -282,7 +289,7 @@ class Driver(object):
         self._remote_responses.update(self._remote_objs)
 
         # set up simultaneous deriv coloring
-        if coloring_mod._use_sparsity:
+        if coloring_mod._use_total_sparsity:
             coloring = self._get_static_coloring()
             if coloring is not None and self.supports['simultaneous_derivatives']:
                 if model._owns_approx_jac:
@@ -291,6 +298,14 @@ class Driver(object):
                     coloring._check_config_total(self)
                 self._setup_simul_coloring()
 
+    def _check_for_missing_objective(self):
+        """
+        Check for missing objective and raise error if no objectives found.
+        """
+        if len(self._objs) == 0:
+            msg = "Driver requires objective to be declared"
+            raise RuntimeError(msg)
+
     def _get_vars_to_record(self, recording_options):
         """
         Get variables to record based on recording options.
@@ -428,7 +443,7 @@ class Driver(object):
             for sub in self._problem.model.system_iter(recurse=True, include_self=True):
                 self._rec_mgr.record_metadata(sub)
 
-    def _get_voi_val(self, name, meta, remote_vois, unscaled=False, ignore_indices=False):
+    def _get_voi_val(self, name, meta, remote_vois, driver_scaling=True, ignore_indices=False):
         """
         Get the value of a variable of interest (objective, constraint, or design var).
 
@@ -443,8 +458,10 @@ class Driver(object):
         remote_vois : dict
             Dict containing (owning_rank, size) for all remote vois of a particular
             type (design var, constraint, or objective).
-        unscaled : bool
-            Set to True if unscaled (physical) design variables are desired.
+        driver_scaling : bool
+            When True, return values that are scaled according to either the adder and scaler or
+            the ref and ref0 values that were specified when add_design_var, add_objective, and
+            add_constraint were called on the model. Default is True.
         ignore_indices : bool
             Set to True if the full array is desired, not just those indicated by indices.
 
@@ -495,7 +512,7 @@ class Driver(object):
             else:
                 val = vec[name][indices]
 
-        if self._has_scaling and not unscaled:
+        if self._has_scaling and driver_scaling:
             # Scale design variable values
             adder = meta['adder']
             if adder is not None:
@@ -507,7 +524,7 @@ class Driver(object):
 
         return val
 
-    def get_design_var_values(self, filter=None, unscaled=False, ignore_indices=False):
+    def get_design_var_values(self, filter=None, driver_scaling=True, ignore_indices=False):
         """
         Return the design variable values.
 
@@ -517,8 +534,10 @@ class Driver(object):
         ----------
         filter : list
             List of desvar names used by recorders.
-        unscaled : bool
-            Set to True if unscaled (physical) design variables are desired.
+        driver_scaling : bool
+            When True, return values that are scaled according to either the adder and scaler or
+            the ref and ref0 values that were specified when add_design_var, add_objective, and
+            add_constraint were called on the model. Default is True.
         ignore_indices : bool
             Set to True if the full array is desired, not just those indicated by indices.
 
@@ -533,7 +552,8 @@ class Driver(object):
             # use all the designvars
             dvs = self._designvars
 
-        return {n: self._get_voi_val(n, self._designvars[n], self._remote_dvs, unscaled=unscaled,
+        return {n: self._get_voi_val(n, self._designvars[n], self._remote_dvs,
+                                     driver_scaling=driver_scaling,
                                      ignore_indices=ignore_indices) for n in dvs}
 
     def set_design_var(self, name, value):
@@ -565,8 +585,8 @@ class Driver(object):
             desvar = problem.model._outputs._views_flat[name]
             desvar[indices] = value
 
+            # Undo driver scaling when setting design var values into model.
             if self._has_scaling:
-                # Scale design variable values
                 scaler = meta['scaler']
                 if scaler is not None:
                     desvar[indices] *= 1.0 / scaler
@@ -596,14 +616,16 @@ class Driver(object):
 
         return {n: self._get_voi_val(n, self._responses[n], self._remote_objs) for n in resps}
 
-    def get_objective_values(self, unscaled=False, filter=None, ignore_indices=False):
+    def get_objective_values(self, driver_scaling=True, filter=None, ignore_indices=False):
         """
         Return objective values.
 
         Parameters
         ----------
-        unscaled : bool
-            Set to True if unscaled (physical) design variables are desired.
+        driver_scaling : bool
+            When True, return values that are scaled according to either the adder and scaler or
+            the ref and ref0 values that were specified when add_design_var, add_objective, and
+            add_constraint were called on the model. Default is True.
         filter : list
             List of objective names used by recorders.
         ignore_indices : bool
@@ -619,11 +641,12 @@ class Driver(object):
         else:
             objs = self._objs
 
-        return {n: self._get_voi_val(n, self._objs[n], self._remote_objs, unscaled=unscaled,
+        return {n: self._get_voi_val(n, self._objs[n], self._remote_objs,
+                                     driver_scaling=driver_scaling,
                                      ignore_indices=ignore_indices)
                 for n in objs}
 
-    def get_constraint_values(self, ctype='all', lintype='all', unscaled=False, filter=None,
+    def get_constraint_values(self, ctype='all', lintype='all', driver_scaling=True, filter=None,
                               ignore_indices=False):
         """
         Return constraint values.
@@ -636,8 +659,10 @@ class Driver(object):
         lintype : string
             Default is 'all'. Optionally return just the linear constraints
             with 'linear' or the nonlinear constraints with 'nonlinear'.
-        unscaled : bool
-            Set to True if unscaled (physical) design variables are desired.
+        driver_scaling : bool
+            When True, return values that are scaled according to either the adder and scaler or
+            the ref and ref0 values that were specified when add_design_var, add_objective, and
+            add_constraint were called on the model. Default is True.
         filter : list
             List of constraint names used by recorders.
         ignore_indices : bool
@@ -669,7 +694,8 @@ class Driver(object):
             if ctype == 'ineq' and meta['equals'] is not None:
                 continue
 
-            con_dict[name] = self._get_voi_val(name, meta, self._remote_cons, unscaled=unscaled,
+            con_dict[name] = self._get_voi_val(name, meta, self._remote_cons,
+                                               driver_scaling=driver_scaling,
                                                ignore_indices=ignore_indices)
 
         return con_dict
@@ -786,7 +812,11 @@ class Driver(object):
                 if total_jac is None:
                     total_jac = _TotalJacInfo(problem, of, wrt, global_names,
                                               return_format, approx=True, debug_print=debug_print)
-                    self._total_jac = total_jac
+
+                    # Don't cache linear constraint jacobian
+                    if not total_jac.has_lin_cons:
+                        self._total_jac = total_jac
+
                     totals = total_jac.compute_totals_approx(initialize=True)
                 else:
                     totals = total_jac.compute_totals_approx()
@@ -798,9 +828,9 @@ class Driver(object):
                 total_jac = _TotalJacInfo(problem, of, wrt, global_names, return_format,
                                           debug_print=debug_print)
 
-            # don't cache linear constraint jacobian
-            if not total_jac.has_lin_cons:
-                self._total_jac = total_jac
+                # don't cache linear constraint jacobian
+                if not total_jac.has_lin_cons:
+                    self._total_jac = total_jac
 
             self._recording_iter.stack.append(('_compute_totals', 0))
 
@@ -827,17 +857,17 @@ class Driver(object):
         filt = self._filtered_vars_to_record
 
         if opts['record_desvars']:
-            des_vars = self.get_design_var_values(unscaled=True, ignore_indices=True)
+            des_vars = self.get_design_var_values(driver_scaling=False, ignore_indices=True)
         else:
             des_vars = {}
 
         if opts['record_objectives']:
-            obj_vars = self.get_objective_values(unscaled=True, ignore_indices=True)
+            obj_vars = self.get_objective_values(driver_scaling=False, ignore_indices=True)
         else:
             obj_vars = {}
 
         if opts['record_constraints']:
-            con_vars = self.get_constraint_values(unscaled=True, ignore_indices=True)
+            con_vars = self.get_constraint_values(driver_scaling=False, ignore_indices=True)
         else:
             con_vars = {}
 
@@ -1056,12 +1086,12 @@ class Driver(object):
             return coloring
 
         if coloring is coloring_mod._STD_COLORING_FNAME or isinstance(coloring, string_types):
-            if coloring is _STD_COLORING_FNAME:
+            if coloring is coloring_mod._STD_COLORING_FNAME:
                 fname = self._get_total_coloring_fname()
             else:
                 fname = coloring
             print("loading total coloring from file %s" % fname)
-            coloring = info['coloring'] = Coloring.load(fname)
+            coloring = info['coloring'] = coloring_mod.Coloring.load(fname)
             info.update(coloring._meta)
             return coloring
 
@@ -1075,7 +1105,7 @@ class Driver(object):
         If set_coloring was called with a filename, load the coloring file.
         """
         # command line simul_coloring uses this env var to turn pre-existing coloring off
-        if not coloring_mod._use_sparsity:
+        if not coloring_mod._use_total_sparsity:
             return
 
         problem = self._problem
@@ -1111,7 +1141,7 @@ class Driver(object):
             print(len(header) * '-')
 
         if 'desvars' in debug_opt:
-            desvar_vals = self.get_design_var_values(unscaled=True, ignore_indices=True)
+            desvar_vals = self.get_design_var_values(driver_scaling=False, ignore_indices=True)
             if not MPI or MPI.COMM_WORLD.rank == 0:
                 print("Design Vars")
                 if desvar_vals:
@@ -1133,7 +1163,7 @@ class Driver(object):
         Optionally print some debugging information after the model runs.
         """
         if 'nl_cons' in self.options['debug_print']:
-            cons = self.get_constraint_values(lintype='nonlinear', unscaled=True)
+            cons = self.get_constraint_values(lintype='nonlinear', driver_scaling=False)
             if not MPI or MPI.COMM_WORLD.rank == 0:
                 print("Nonlinear constraints")
                 if cons:
@@ -1143,7 +1173,7 @@ class Driver(object):
                 print()
 
         if 'ln_cons' in self.options['debug_print']:
-            cons = self.get_constraint_values(lintype='linear', unscaled=True)
+            cons = self.get_constraint_values(lintype='linear', driver_scaling=False)
             if not MPI or MPI.COMM_WORLD.rank == 0:
                 print("Linear constraints")
                 if cons:
@@ -1153,7 +1183,7 @@ class Driver(object):
                 print()
 
         if 'objs' in self.options['debug_print']:
-            objs = self.get_objective_values(unscaled=True)
+            objs = self.get_objective_values(driver_scaling=False)
             if not MPI or MPI.COMM_WORLD.rank == 0:
                 print("Objectives")
                 if objs:
