@@ -101,7 +101,7 @@ class IndepVarComp(ExplicitComponent):
                                "afterwards.".format(self.pathname))
 
     def add_output(self, name, val=1.0, shape=None, units=None, res_units=None, desc='',
-                   lower=None, upper=None, ref=1.0, ref0=0.0, res_ref=1.0):
+                   lower=None, upper=None, ref=1.0, ref0=0.0, res_ref=None):
         """
         Add an independent variable to this component.
 
@@ -140,8 +140,12 @@ class IndepVarComp(ExplicitComponent):
             the scaled value is 0. Default is 0.
         res_ref : float
             Scaling parameter. The value in the user-defined res_units of this output's residual
-            when the scaled value is 1. Default is 1.
+            when the scaled value is 1. Default is None, which means residual scaling matches
+            output scaling.
         """
+        if res_ref is None:
+            res_ref = ref
+
         kwargs = {'shape': shape, 'units': units, 'res_units': res_units, 'desc': desc,
                   'lower': lower, 'upper': upper, 'ref': ref, 'ref0': ref0,
                   'res_ref': res_ref}
