@@ -4,6 +4,7 @@ from __future__ import division, print_function
 
 import sys
 import os
+import logging
 
 from collections import defaultdict, namedtuple
 from fnmatch import fnmatchcase
@@ -25,7 +26,7 @@ from openmdao.core.total_jac import _TotalJacInfo
 from openmdao.approximation_schemes.complex_step import ComplexStep
 from openmdao.approximation_schemes.finite_difference import FiniteDifference
 from openmdao.solvers.solver import SolverInfo
-from openmdao.error_checking.check_config import check_config
+from openmdao.error_checking.check_config import _default_checks, _all_checks
 from openmdao.recorders.recording_iteration_stack import _RecIteration
 from openmdao.recorders.recording_manager import RecordingManager, record_viewer_data
 from openmdao.utils.record_util import create_local_meta
@@ -38,6 +39,7 @@ from openmdao.utils.units import get_conversion
 from openmdao.utils import coloring as coloring_mod
 from openmdao.utils.name_maps import abs_key2rel_key
 from openmdao.vectors.default_vector import DefaultVector
+from openmdao.utils.logger_utils import get_logger
 import openmdao.utils.coloring as coloring_mod
 
 try:
@@ -126,6 +128,8 @@ class Problem(object):
         after a reconfiguration) you may need to set this to True.
     _color_dir_hash : str
         Hash used to detect collisions of coloring files.
+    __get_remote : bool
+        Flag used to determine when __getitem__ will retrieve remote variables.
     """
 
     _post_setup_func = None
@@ -147,6 +151,9 @@ class Problem(object):
         **options : named args
             All remaining named args are converted to options.
         """
+        # used by the get_val function when get_remote is True
+        self.__get_remote = False
+
         self.cite = CITATION
 
         if comm is None:
@@ -220,6 +227,53 @@ class Problem(object):
                                        desc='Patterns for vars to exclude in recording '
                                             '(processed post-includes)')
 
+    def _get_var_abs_name(self, name):
+        if name in self.model._var_allprocs_abs2meta:
+            return name
+        elif name in self.model._var_allprocs_prom2abs_list['output']:
+            return self.model._var_allprocs_prom2abs_list['output'][name][0]
+        elif name in self.model._var_allprocs_prom2abs_list['input']:
+            abs_names = self.model._var_allprocs_prom2abs_list['input'][name]
+            if len(abs_names) == 1:
+                return abs_names[0]
+            else:
+                raise KeyError("Using promoted name `{}' is ambiguous and matches unconnected "
+                               "inputs %s. Use absolute name to disambiguate.".format(name,
+                                                                                      abs_names))
+
+        raise KeyError("Variable '{}' not found.".format(name))
+
+    def is_local(self, name):
+        """
+        Return True if the named variable or system is local to the current process.
+
+        Parameters
+        ----------
+        name : str
+            Name of a variable or system.
+
+        Returns
+        -------
+        bool
+            True if the named system or variable is local to this process.
+        """
+        if self._setup_status < 1:
+            raise RuntimeError("is_local('{}') was called before setup() completed.".format(name))
+
+        try:
+            abs_name = self._get_var_abs_name(name)
+        except KeyError:
+            sub = self.model._get_subsystem(name)
+            if sub is None:  # either the sub is remote or there is no sub by that name
+                # TODO: raise exception if sub does not exist
+                return False
+            else:
+                # if system has been set up, _var_sizes will be initialized
+                return sub._var_sizes is not None
+
+        # variable exists, but may be remote
+        return abs_name in self.model._var_abs2meta
+
     def __getitem__(self, name):
         """
         Get an output/input variable.
@@ -314,29 +368,35 @@ class Problem(object):
                 abs_name = proms['input'][name][0]
 
             if abs_name in self._remote_var_set:
-                if abs_name in allprocs_meta and allprocs_meta[abs_name]['distributed']:
-                    raise RuntimeError("Retrieval of the full distributed variable '%s' is not "
-                                       "supported." % abs_name)
-                loc_val = val
-                owner = self.model._owning_rank[abs_name]
-                if owner != self.model.comm.rank:
-                    val = None
-                else:
+                if self.__get_remote:
+                    if abs_name in allprocs_meta and allprocs_meta[abs_name]['distributed']:
+                        raise RuntimeError("Retrieval of the full distributed variable '%s' is not "
+                                           "supported." % abs_name)
+                    loc_val = val
                     owner = self.model._owning_rank[abs_name]
-                    if val is _undefined:
+                    if owner != self.model.comm.rank:
                         val = None
-                new_val = self.model.comm.bcast(val, root=owner)
-                if loc_val is not None and loc_val is not _undefined:
-                    val = loc_val
-                else:
-                    val = new_val
+                    else:
+                        owner = self.model._owning_rank[abs_name]
+                        if val is _undefined:
+                            val = None
+                    new_val = self.model.comm.bcast(val, root=owner)
+                    if loc_val is not None and loc_val is not _undefined:
+                        val = loc_val
+                    else:
+                        val = new_val
+                elif val is _undefined:
+                    raise RuntimeError(
+                        "Variable '{}' is not local to rank {}. You can retrieve values from "
+                        "other processes using "
+                        "`problem.get_val(<name>, get_remote=True)`.".format(name, self.comm.rank))
 
         if val is _undefined:
             raise KeyError('Variable name "{}" not found.'.format(name))
 
         return val
 
-    def get_val(self, name, units=None, indices=None):
+    def get_val(self, name, units=None, indices=None, get_remote=False):
         """
         Get an output/input variable.
 
@@ -350,13 +410,24 @@ class Problem(object):
             Units to convert to before upon return.
         indices : int or list of ints or tuple of ints or int ndarray or Iterable or None, optional
             Indices or slice to return.
+        get_remote : bool
+            If True, retrieve the value even if it is on a remote process.  Note that if the
+            variable is remote on ANY process, this function must be called on EVERY process
+            in the Problem's MPI communicator.
 
         Returns
         -------
         float or ndarray
             The requested output/input variable.
         """
-        val = self[name]
+        if get_remote:
+            self.__get_remote = True
+            try:
+                val = self[name]
+            finally:
+                self.__get_remote = False
+        else:
+            val = self[name]
 
         if indices is not None:
             val = val[indices]
@@ -444,8 +515,10 @@ class Problem(object):
                 self.model._discrete_inputs[abs_name] = value
             else:
                 # might be a remote var.  If so, just do nothing on this proc
-                if not (name in all_proms['input'] or name in all_proms['output'] or
-                        name in self.model._var_allprocs_abs2meta):
+                if abs_name in self.model._var_allprocs_abs2meta:
+                    print("Variable '{}' is remote on rank {}.  "
+                          "Local assignment ignored.".format(name, self.comm.rank))
+                else:
                     raise KeyError('Variable name "{}" not found.'.format(name))
 
     def set_val(self, name, value, units=None, indices=None):
@@ -850,7 +923,8 @@ class Problem(object):
         coloring = driver._coloring_info['coloring']
         if coloring is coloring_mod._STD_COLORING_FNAME:
             coloring = driver._get_static_coloring()
-        if coloring and coloring is not coloring_mod._DYN_COLORING and coloring_mod._use_sparsity:
+        if (coloring and coloring is not coloring_mod._DYN_COLORING and
+                coloring_mod._use_total_sparsity):
             # if we're using simultaneous total derivatives then our effective size is less
             # than the full size
             if coloring._fwd and coloring._rev:
@@ -878,7 +952,11 @@ class Problem(object):
             self.set_solver_print(level=items[0], depth=items[1], type_=items[2])
 
         if self._check and self.comm.rank == 0:
-            check_config(self, self._logger)
+            if self._check is True:
+                checks = _default_checks
+            else:
+                checks = self._check
+            self.check_config(self._logger, checks=checks)
 
         if self._setup_status < 2:
             self._setup_status = 2
@@ -1057,7 +1135,7 @@ class Problem(object):
                                 dinputs.set_const(0.0)
                                 dstate.set_const(0.0)
 
-                                # Dictionary access returns a scaler for 1d input, and we
+                                # Dictionary access returns a scalar for 1d input, and we
                                 # need a vector for clean code, so use _views_flat.
                                 flat_view[idx] = 1.0
 
@@ -1274,8 +1352,9 @@ class Problem(object):
         compact_print : bool
             Set to True to just print the essentials, one line per unknown-param pair.
         driver_scaling : bool
-            Set to True to scale derivative values by the quantities specified when the desvars and
-            responses were added. Default if False, which is unscaled.
+            When True, return derivatives that are scaled according to either the adder and scaler
+            or the ref and ref0 values that were specified when add_design_var, add_objective, and
+            add_constraint were called on the model. Default is False, which is unscaled.
         abs_err_tol : float
             Threshold value for absolute error.  Errors about this value will have a '*' displayed
             next to them in output, making them easy to search for. Default is 1.0E-6.
@@ -1386,8 +1465,9 @@ class Problem(object):
         debug_print : bool
             Set to True to print out some debug information during linear solve.
         driver_scaling : bool
-            Set to True to scale derivative values by the quantities specified when the desvars and
-            responses were added. Default if False, which is unscaled.
+            When True, return derivatives that are scaled according to either the adder and scaler
+            or the ref and ref0 values that were specified when add_design_var, add_objective, and
+            add_constraint were called on the model. Default is False, which is unscaled.
 
         Returns
         -------
@@ -1617,6 +1697,35 @@ class Problem(object):
 
         return
 
+    def check_config(self, logger=None, checks=None, out_file='openmdao_checks.out'):
+        """
+        Perform optional error checks on a Problem.
+
+        Parameters
+        ----------
+        logger : object
+            Logging object.
+        checks : list of str or None
+            List of specific checks to be performed.
+        out_file : str or None
+            If not None, output will be written to this file in addition to stdout.
+        """
+        if logger is None:
+            logger = get_logger('check_config', out_file=out_file, use_format=True)
+
+        if checks is None:
+            checks = sorted(_default_checks)
+        elif checks == 'all':
+            checks = sorted(_all_checks)
+
+        for c in checks:
+            if c not in _all_checks:
+                print("WARNING: '%s' is not a recognized check.  Available checks are: %s" %
+                      (c, sorted(_all_checks)))
+                continue
+            logger.info('checking %s' % c)
+            _all_checks[c](self, logger)
+
 
 def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out_stream,
                               compact_print, system_list, global_options, totals=False,
@@ -1855,7 +1964,7 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
                                 break
 
                         if error_string:  # Any error string indicates that at least one of the
-                                            # derivative calcs is greater than the rel tolerance
+                            #  derivative calcs is greater than the rel tolerance
                             num_bad_jacs += 1
 
                         if out_stream:
