@@ -16,7 +16,7 @@ class TestConnections(unittest.TestCase):
         self.setup_model(None, None)
 
     def setup_model(self, c1meta=None, c3meta=None):
-        self.p = Problem(model=Group())
+        self.p = Problem()
         root = self.p.model
 
         if c1meta is None:
@@ -36,7 +36,7 @@ class TestConnections(unittest.TestCase):
         self.C4 = self.G4.add_subsystem("C4", ExecComp('y=x*2.0'))
 
     def test_no_conns(self):
-        self.p.setup(check=False)
+        self.p.setup()
 
         self.p['G1.G2.C1.x'] = 111.
         self.p['G3.G4.C3.x'] = 222.
@@ -52,7 +52,7 @@ class TestConnections(unittest.TestCase):
         raise unittest.SkipTest("explicit input-input connections not supported yet")
         self.p.model.connect('G3.G4.C3.x', 'G3.G4.C4.x')  # connect inputs
         self.p.model.connect('G1.G2.C2.x', 'G3.G4.C3.x')  # connect src to one of connected inputs
-        self.p.setup(check=False)
+        self.p.setup()
 
         self.p['G1.G2.C2.x'] = 999.
         self.assertEqual(self.C3._inputs['x'], 0.)
@@ -96,14 +96,13 @@ class TestConnections(unittest.TestCase):
                 outputs['y2'] = np.sum(x2)
 
         p = Problem()
-        p.model = Group()
         p.model.add_subsystem('src', Src())
         p.model.add_subsystem('tgt', Tgt())
 
         p.model.connect('src.y1', 'tgt.x1')
         p.model.connect('src.y2', 'tgt.x2')
 
-        p.setup(check=False)
+        p.setup()
         p.run_model()
 
         self.assertEqual(p['tgt.y1'], 12.0)
@@ -153,7 +152,6 @@ class TestConnections(unittest.TestCase):
                 outputs['y3'] = np.sum(x3)
 
         top = Problem()
-        top.model = Group()
         top.model.add_subsystem('src', Src())
         top.model.add_subsystem('tgt', Tgt())
 
@@ -161,7 +159,7 @@ class TestConnections(unittest.TestCase):
         top.model.connect('src.y2', 'tgt.x2', src_indices=(0, 1))
         top.model.connect('src.y3', 'tgt.x3')
 
-        top.setup(check=False)
+        top.setup()
         top.run_model()
 
         self.assertEqual(top['tgt.y1'], 6.0)
@@ -197,7 +195,7 @@ class TestConnections(unittest.TestCase):
         self.p.model.connect('G1.G2.C1.x', 'G3.G4.C3.x')
 
         try:
-            self.p.setup(check=False)
+            self.p.setup()
         except Exception as err:
             self.assertTrue(
                 "The following sourceless connected inputs have different initial values: "
@@ -216,7 +214,7 @@ class TestConnections(unittest.TestCase):
         self.p.model.connect('G1.G2.C1.x', 'G3.G4.C3.x')
 
         try:
-            self.p.setup(check=False)
+            self.p.setup()
         except Exception as err:
             msg = "The following connected inputs have no source and different units: " \
                   "[('G1.G2.C1.x', 'ft'), ('G3.G4.C3.x', 'inch')]. " \
@@ -235,7 +233,7 @@ class TestConnections(unittest.TestCase):
         self.p.model.connect('G3.G4.C3.x', 'G1.G2.C1.x')
 
         try:
-            self.p.setup(check=False)
+            self.p.setup()
         except Exception as err:
             msg = "The following connected inputs have no source and different units: " \
                   "[('G1.G2.C1.x', 'ft'), ('G3.G4.C3.x', 'inch')]. " \
@@ -247,7 +245,7 @@ class TestConnections(unittest.TestCase):
     def test_diff_conn_input_units_w_src(self):
         raise unittest.SkipTest("no compatability checking of connected inputs yet")
 
-        p = Problem(model=Group())
+        p = Problem()
         root = p.model
 
         num_comps = 50
@@ -268,7 +266,7 @@ class TestConnections(unittest.TestCase):
             root.connect("C%d.x" % (i-1), "C%d.x" % i)
 
         try:
-            p.setup(check=False)
+            p.setup()
         except Exception as err:
             self.assertTrue("The following connected inputs have no source and different units" in
                             str(err))
@@ -281,14 +279,14 @@ class TestConnections(unittest.TestCase):
 
         root.connect('desvars.dvar1', 'C10.x')
 
-        p.setup(check=False)
+        p.setup()
 
 
 class TestConnectionsPromoted(unittest.TestCase):
 
     def test_inp_inp_promoted_no_src(self):
 
-        p = Problem(model=Group())
+        p = Problem()
         root = p.model
 
         G1 = root.add_subsystem("G1", Group())
@@ -312,7 +310,7 @@ class TestConnectionsPromoted(unittest.TestCase):
                          "[G3.G4.C3.x, G3.G4.C4.x] that are not connected to an output variable.")
 
     def test_inp_inp_promoted_w_prom_src(self):
-        p = Problem(model=Group())
+        p = Problem()
         root = p.model
 
         G1 = root.add_subsystem("G1", Group(), promotes=['x'])
@@ -325,7 +323,7 @@ class TestConnectionsPromoted(unittest.TestCase):
         C3 = G4.add_subsystem("C3", ExecComp('y=x*2.0'), promotes=['x'])
         C4 = G4.add_subsystem("C4", ExecComp('y=x*2.0'), promotes=['x'])
 
-        p.setup(check=False)
+        p.setup()
         p.set_solver_print(level=0)
 
         # setting promoted name will set the value into the outputs, but will
@@ -337,7 +335,7 @@ class TestConnectionsPromoted(unittest.TestCase):
         self.assertEqual(C4._inputs['x'], 999.)
 
     def test_inp_inp_promoted_w_explicit_src(self):
-        p = Problem(model=Group())
+        p = Problem()
         root = p.model
 
         G1 = root.add_subsystem("G1", Group())
@@ -351,7 +349,7 @@ class TestConnectionsPromoted(unittest.TestCase):
         C4 = G4.add_subsystem("C4", ExecComp('y=x*2.0'), promotes=['x'])
 
         p.model.connect('G1.x', 'G3.x')
-        p.setup(check=False)
+        p.setup()
         p.set_solver_print(level=0)
 
         # setting promoted name will set the value into the outputs, but will
@@ -364,7 +362,7 @@ class TestConnectionsPromoted(unittest.TestCase):
 
     def test_unit_conv_message(self):
         raise unittest.SkipTest("no units yet")
-        prob = Problem(model=Group())
+        prob = Problem()
         root = prob.model
 
         root.add_subsystem("C1", ExecComp('y=x*2.0', units={'x': 'ft'}), promotes=['x'])
@@ -372,7 +370,7 @@ class TestConnectionsPromoted(unittest.TestCase):
         root.add_subsystem("C3", ExecComp('y=x*2.0', units={'x': 'm'}), promotes=['x'])
 
         try:
-            prob.setup(check=False)
+            prob.setup()
         except Exception as err:
             msg = "The following connected inputs are promoted to 'x', but have different units: " \
                   "[('C1.x', 'ft'), ('C2.x', 'inch'), ('C3.x', 'm')]. " \
@@ -383,7 +381,7 @@ class TestConnectionsPromoted(unittest.TestCase):
 
         # Remedy the problem with an Indepvarcomp
 
-        prob = Problem(model=Group())
+        prob = Problem()
         root = prob.model
 
         root.add_subsystem("C1", ExecComp('y=x*2.0', units={'x': 'ft'}), promotes=['x'])
@@ -391,12 +389,12 @@ class TestConnectionsPromoted(unittest.TestCase):
         root.add_subsystem("C3", ExecComp('y=x*2.0', units={'x': 'm'}), promotes=['x'])
         root.add_subsystem('p', IndepVarComp('x', 1.0, units='cm'), promotes=['x'])
 
-        prob.setup(check=False)
+        prob.setup()
 
     def test_overlapping_system_names(self):
         # This ensures that _setup_connections does not think g1 and g1a are the same system
         prob = Problem()
-        model = prob.model = Group()
+        model = prob.model
 
         g1 = model.add_subsystem('g1', Group())
         g1a = model.add_subsystem('g1a', Group())
@@ -441,7 +439,7 @@ class TestConnectionsIndices(unittest.TestCase):
                     r" Expected \(2.*,\) but got \(1.*,\).")
 
         with assertRaisesRegex(self, ValueError, expected):
-            self.prob.setup(check=False)
+            self.prob.setup()
 
     def test_bad_length(self):
         # Should not be allowed because the length of src_indices is greater than
@@ -453,7 +451,7 @@ class TestConnectionsIndices(unittest.TestCase):
                     r"The target shape is \(2.*,\) but indices are \(3.*,\).")
 
         with assertRaisesRegex(self, ValueError, expected):
-            self.prob.setup(check=False)
+            self.prob.setup()
 
     def test_bad_value(self):
         # Should not be allowed because the index value within src_indices is outside
@@ -466,7 +464,7 @@ class TestConnectionsIndices(unittest.TestCase):
                     "size 5.")
 
         try:
-            self.prob.setup(check=False)
+            self.prob.setup()
         except ValueError as err:
             self.assertEqual(str(err), expected)
         else:
