@@ -8,31 +8,33 @@ from six import assertRaisesRegex, StringIO, assertRegex
 
 import numpy as np
 
+import openmdao.api as om
 from openmdao.core.group import get_relevant_vars
 from openmdao.core.driver import Driver
-from openmdao.api import Problem, IndepVarComp, NonlinearBlockGS, ScipyOptimizeDriver, \
-    ExecComp, Group, NewtonSolver, ImplicitComponent, ScipyKrylov, ExplicitComponent, \
-    ImplicitComponent, ParallelGroup, BroydenSolver
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.devtools.problem_viewer.problem_viewer import _get_viewer_data
 from openmdao.test_suite.components.paraboloid import Paraboloid
 from openmdao.test_suite.components.sellar import StateConnection, \
      SellarDis1withDerivatives, SellarDis2withDerivatives
+from openmdao.utils.assert_utils import assert_rel_error
 
 
-class ModCompEx(ExplicitComponent):
+class ModCompEx(om.ExplicitComponent):
     def __init__(self, modval, **kwargs):
         super(ModCompEx, self).__init__(**kwargs)
         self.modval = modval
 
     def setup(self):
+        self.add_input('a', val=10.)
+        self.add_output('b', val=0.)
         self.add_discrete_input('x', val=10)
         self.add_discrete_output('y', val=0)
 
     def compute(self, inputs, outputs, discrete_inputs, discrete_outputs):
+        outputs['b'] = inputs['a']*2.
         discrete_outputs['y'] = discrete_inputs['x'] % self.modval
 
 
-class ModCompIm(ImplicitComponent):
+class ModCompIm(om.ImplicitComponent):
     def __init__(self, modval, **kwargs):
         super(ModCompIm, self).__init__(**kwargs)
         self.modval = modval
@@ -48,7 +50,7 @@ class ModCompIm(ImplicitComponent):
         discrete_outputs['y'] = discrete_inputs['x'] % self.modval
 
 
-class CompDiscWDerivs(ExplicitComponent):
+class CompDiscWDerivs(om.ExplicitComponent):
     def setup(self):
         self.add_discrete_input('N', 2)
         self.add_discrete_output('Nout', 2)
@@ -82,7 +84,7 @@ class CompDiscWDerivsImplicit(StateConnection):
         super(CompDiscWDerivsImplicit, self).linearize(inputs, outputs, J)
 
 
-class MixedCompDiscIn(ExplicitComponent):
+class MixedCompDiscIn(om.ExplicitComponent):
     def __init__(self, mult, **kwargs):
         super(MixedCompDiscIn, self).__init__(**kwargs)
         self.mult = mult
@@ -95,7 +97,7 @@ class MixedCompDiscIn(ExplicitComponent):
         outputs['y'] = discrete_inputs['x'] * self.mult
 
 
-class MixedCompDiscOut(ExplicitComponent):
+class MixedCompDiscOut(om.ExplicitComponent):
     def __init__(self, mult, **kwargs):
         super(MixedCompDiscOut, self).__init__(**kwargs)
         self.mult = mult
@@ -108,7 +110,7 @@ class MixedCompDiscOut(ExplicitComponent):
         discrete_outputs['y'] = inputs['x'] * self.mult
 
 
-class InternalDiscreteGroup(Group):
+class InternalDiscreteGroup(om.Group):
     # this group has an internal discrete connection with continuous external vars,
     # so it can be spliced into an existing continuous model to test for discrete
     # var error checking.
@@ -154,7 +156,7 @@ class _DiscreteVal(object):
         return self
 
 
-class PathCompEx(ExplicitComponent):
+class PathCompEx(om.ExplicitComponent):
 
     def setup(self):
         self.add_discrete_input('x', val=self.pathname)
@@ -164,7 +166,7 @@ class PathCompEx(ExplicitComponent):
         discrete_outputs['y'] = discrete_inputs['x'] + self.pathname + '/'
 
 
-class ObjAdderCompEx(ExplicitComponent):
+class ObjAdderCompEx(om.ExplicitComponent):
     def __init__(self, val, **kwargs):
         super(ObjAdderCompEx, self).__init__(**kwargs)
         self.val = val
@@ -180,10 +182,10 @@ class ObjAdderCompEx(ExplicitComponent):
 class DiscreteTestCase(unittest.TestCase):
 
     def test_simple_run_once(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', IndepVarComp())
+        indep = model.add_subsystem('indep', om.IndepVarComp())
         indep.add_discrete_output('x', 11)
         model.add_subsystem('comp', ModCompEx(3))
 
@@ -195,10 +197,10 @@ class DiscreteTestCase(unittest.TestCase):
         assert_rel_error(self, prob['comp.y'], 2)
 
     def test_simple_run_once_promoted(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', IndepVarComp(), promotes=['*'])
+        indep = model.add_subsystem('indep', om.IndepVarComp(), promotes=['*'])
         indep.add_discrete_output('x', 11)
         model.add_subsystem('comp', ModCompEx(3), promotes=['*'])
 
@@ -208,10 +210,10 @@ class DiscreteTestCase(unittest.TestCase):
         assert_rel_error(self, prob['y'], 2)
 
     def test_simple_run_once_implicit(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', IndepVarComp())
+        indep = model.add_subsystem('indep', om.IndepVarComp())
         indep.add_discrete_output('x', 11)
         model.add_subsystem('comp', ModCompIm(3))
 
@@ -222,11 +224,81 @@ class DiscreteTestCase(unittest.TestCase):
 
         assert_rel_error(self, prob['comp.y'], 2)
 
-    def test_float_to_discrete_error(self):
-        prob = Problem()
+    def test_list_inputs_outputs(self):
+        prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', IndepVarComp())
+        indep = model.add_subsystem('indep', om.IndepVarComp())
+        indep.add_discrete_output('x', 11)
+
+        model.add_subsystem('expl', ModCompEx(3))
+        model.add_subsystem('impl', ModCompIm(3))
+
+        model.connect('indep.x', ['expl.x', 'impl.x'])
+
+        prob.setup()
+        prob.run_model()
+
+        #
+        # list inputs, not hierarchical
+        #
+        stream = StringIO()
+        prob.model.list_inputs(values=True, hierarchical=False, out_stream=stream)
+        text = stream.getvalue()
+
+        self.assertEqual(1, text.count("3 Input(s) in 'model'"))
+
+        # make sure they are in the correct order
+        self.assertTrue(text.find('expl.a') < text.find('expl.x') < text.find('impl.x'))
+
+        #
+        # list inputs, hierarchical
+        #
+        stream = StringIO()
+        prob.model.list_inputs(values=True, hierarchical=True, out_stream=stream)
+        text = stream.getvalue()
+
+        self.assertEqual(1, text.count("3 Input(s) in 'model'"))
+        self.assertEqual(1, text.count('top'))
+        self.assertEqual(1, text.count('  expl'))
+        self.assertEqual(1, text.count('    a'))
+        self.assertEqual(1, text.count('  impl'))
+        self.assertEqual(2, text.count('    x'))      # both implicit & explicit
+
+        #
+        # list outputs, not hierarchical
+        #
+        stream = StringIO()
+        prob.model.list_outputs(values=True, residuals=True, hierarchical=False, out_stream=stream)
+        text = stream.getvalue()
+
+        self.assertEqual(text.count('3 Explicit Output'), 1)
+        self.assertEqual(text.count('1 Implicit Output'), 1)
+
+        # make sure they are in the correct order
+        self.assertTrue(text.find('indep.x') < text.find('expl.b') <
+                        text.find('expl.y') < text.find('impl.y'))
+
+        #
+        # list outputs, hierarchical
+        #
+        stream = StringIO()
+        prob.model.list_outputs(values=True, residuals=True, hierarchical=True, out_stream=stream)
+        text = stream.getvalue()
+
+        self.assertEqual(text.count('top'), 2)        # both implicit & explicit
+        self.assertEqual(text.count('  indep'), 1)
+        self.assertEqual(text.count('    x'), 1)
+        self.assertEqual(text.count('  expl'), 1)
+        self.assertEqual(text.count('    b'), 1)
+        self.assertEqual(text.count('  impl'), 1)
+        self.assertEqual(text.count('    y'), 2)      # both implicit & explicit
+
+    def test_float_to_discrete_error(self):
+        prob = om.Problem()
+        model = prob.model
+
+        indep = model.add_subsystem('indep', om.IndepVarComp())
         indep.add_output('x', 1.0)
         model.add_subsystem('comp', ModCompEx(3))
 
@@ -238,12 +310,12 @@ class DiscreteTestCase(unittest.TestCase):
                          "Can't connect discrete output 'indep.x' to continuous input 'comp.x'.")
 
     def test_discrete_to_float_error(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', IndepVarComp())
+        indep = model.add_subsystem('indep', om.IndepVarComp())
         indep.add_discrete_output('x', 1)
-        model.add_subsystem('comp', ExecComp("y=2.0*x"))
+        model.add_subsystem('comp', om.ExecComp("y=2.0*x"))
 
         model.connect('indep.x', 'comp.x')
 
@@ -253,10 +325,10 @@ class DiscreteTestCase(unittest.TestCase):
                          "Can't connect discrete output 'indep.x' to continuous input 'comp.x'.")
 
     def test_discrete_mismatch_error(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', IndepVarComp())
+        indep = model.add_subsystem('indep', om.IndepVarComp())
         indep.add_discrete_output('x', val='foo')
         model.add_subsystem('comp', ModCompEx(3))
 
@@ -269,10 +341,10 @@ class DiscreteTestCase(unittest.TestCase):
 
     def test_driver_discrete_enforce_int(self):
         # Drivers require discrete vars to be int or ndarrays of int.
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', IndepVarComp())
+        indep = model.add_subsystem('indep', om.IndepVarComp())
         indep.add_discrete_output('x', 11)
         model.add_subsystem('comp', ModCompIm(3))
 
@@ -315,10 +387,10 @@ class DiscreteTestCase(unittest.TestCase):
         prob.run_driver()
 
     def test_discrete_deriv_explicit(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', IndepVarComp())
+        indep = model.add_subsystem('indep', om.IndepVarComp())
         indep.add_output('x', 1.0)
 
         comp = model.add_subsystem('comp', CompDiscWDerivs())
@@ -335,10 +407,10 @@ class DiscreteTestCase(unittest.TestCase):
         np.testing.assert_almost_equal(J, np.array([[3.]]))
 
     def test_discrete_deriv_implicit(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', IndepVarComp())
+        indep = model.add_subsystem('indep', om.IndepVarComp())
         indep.add_output('x', 1.0, ref=10.)
         indep.add_discrete_output('N', 1)
 
@@ -359,23 +431,23 @@ class DiscreteTestCase(unittest.TestCase):
         np.testing.assert_almost_equal(J, np.array([[-1]]))
 
     def test_deriv_err(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', IndepVarComp(), promotes_outputs=['x'])
+        indep = model.add_subsystem('indep', om.IndepVarComp(), promotes_outputs=['x'])
         indep.add_output('x', 1.0)
 
-        G = model.add_subsystem('G', Group(), promotes_inputs=['x'])
+        G = model.add_subsystem('G', om.Group(), promotes_inputs=['x'])
 
         G1 = G.add_subsystem('G1', InternalDiscreteGroup(), promotes_inputs=['x'], promotes_outputs=['y'])
 
-        G2 = G.add_subsystem('G2', Group(), promotes_inputs=['x'])
-        G2.add_subsystem('C2_1', ExecComp('y=3*x'), promotes_inputs=['x'])
-        G2.add_subsystem('C2_2', ExecComp('y=4*x'), promotes_outputs=['y'])
+        G2 = G.add_subsystem('G2', om.Group(), promotes_inputs=['x'])
+        G2.add_subsystem('C2_1', om.ExecComp('y=3*x'), promotes_inputs=['x'])
+        G2.add_subsystem('C2_2', om.ExecComp('y=4*x'), promotes_outputs=['y'])
         G2.connect('C2_1.y', 'C2_2.x')
 
-        model.add_subsystem('C3', ExecComp('y=3+x'))
-        model.add_subsystem('C4', ExecComp('y=4+x'))
+        model.add_subsystem('C3', om.ExecComp('y=3+x'))
+        model.add_subsystem('C4', om.ExecComp('y=4+x'))
 
         model.connect('G.y', 'C3.x')
         model.connect('G.G2.y', 'C4.x')
@@ -398,16 +470,16 @@ class DiscreteTestCase(unittest.TestCase):
 
 class SolverDiscreteTestCase(unittest.TestCase):
     def _setup_model(self, solver_class):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         proms = ['x', 'z', 'y1', 'state_eq.y2_actual', 'state_eq.y2_command', 'd1.y2', 'd2.y2']
-        sub = model.add_subsystem('sub', Group(), promotes=proms)
+        sub = model.add_subsystem('sub', om.Group(), promotes=proms)
 
-        subgrp = sub.add_subsystem('state_eq_group', Group(),
+        subgrp = sub.add_subsystem('state_eq_group', om.Group(),
                                    promotes=['state_eq.y2_actual', 'state_eq.y2_command'])
         subgrp.add_subsystem('state_eq', StateConnection())
 
@@ -417,13 +489,13 @@ class SolverDiscreteTestCase(unittest.TestCase):
         model.connect('state_eq.y2_command', 'd1.y2')
         model.connect('d2.y2', 'state_eq.y2_actual')
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                               z=np.array([0.0, 0.0]), x=0.0, y1=0.0, y2=0.0),
-                           promotes=['x', 'z', 'y1', 'obj'])
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0, y1=0.0, y2=0.0),
+                            promotes=['x', 'z', 'y1', 'obj'])
         model.connect('d2.y2', 'obj_cmp.y2')
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2'])
 
         # splice a group containing discrete vars into the model
         model.add_subsystem('discrete_g', InternalDiscreteGroup())
@@ -433,12 +505,12 @@ class SolverDiscreteTestCase(unittest.TestCase):
         model.nonlinear_solver = solver_class()
 
         prob.set_solver_print(level=0)
-        prob.setup(check=False)
+        prob.setup()
 
         return prob
 
     def test_discrete_err_newton(self):
-        prob = self._setup_model(NewtonSolver)
+        prob = self._setup_model(om.NewtonSolver)
 
         with self.assertRaises(Exception) as ctx:
             prob.run_model()
@@ -447,7 +519,7 @@ class SolverDiscreteTestCase(unittest.TestCase):
                          "System '' has a NewtonSolver solver and contains discrete outputs ['discrete_g.C1.y'].")
 
     def test_discrete_err_broyden(self):
-        prob = self._setup_model(BroydenSolver)
+        prob = self._setup_model(om.BroydenSolver)
 
         with self.assertRaises(Exception) as ctx:
             prob.run_model()
@@ -458,20 +530,20 @@ class SolverDiscreteTestCase(unittest.TestCase):
 
 class DiscretePromTestCase(unittest.TestCase):
     def test_str_pass(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', IndepVarComp(), promotes_outputs=['x'])
+        indep = model.add_subsystem('indep', om.IndepVarComp(), promotes_outputs=['x'])
         indep.add_discrete_output('x', 'indep/')
 
-        G = model.add_subsystem('G', ParallelGroup(), promotes_inputs=['x'])
+        G = model.add_subsystem('G', om.ParallelGroup(), promotes_inputs=['x'])
 
-        G1 = G.add_subsystem('G1', Group(), promotes_inputs=['x'], promotes_outputs=['y'])
+        G1 = G.add_subsystem('G1', om.Group(), promotes_inputs=['x'], promotes_outputs=['y'])
         G1.add_subsystem('C1_1', PathCompEx(), promotes_inputs=['x'])
         G1.add_subsystem('C1_2', PathCompEx(), promotes_outputs=['y'])
         G1.connect('C1_1.y', 'C1_2.x')
 
-        G2 = G.add_subsystem('G2', Group(), promotes_inputs=['x'])
+        G2 = G.add_subsystem('G2', om.Group(), promotes_inputs=['x'])
         G2.add_subsystem('C2_1', PathCompEx(), promotes_inputs=['x'])
         G2.add_subsystem('C2_2', PathCompEx(), promotes_outputs=['y'])
         G2.connect('C2_1.y', 'C2_2.x')
@@ -495,20 +567,20 @@ class DiscretePromTestCase(unittest.TestCase):
         self.assertEqual(prob['C4.y'], 'foobar/G.G2.C2_1/G.G2.C2_2/C4/')
 
     def test_obj_pass(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        indep = model.add_subsystem('indep', IndepVarComp(), promotes_outputs=['x'])
+        indep = model.add_subsystem('indep', om.IndepVarComp(), promotes_outputs=['x'])
         indep.add_discrete_output('x', _DiscreteVal(19))
 
-        G = model.add_subsystem('G', ParallelGroup(), promotes_inputs=['x'])
+        G = model.add_subsystem('G', om.ParallelGroup(), promotes_inputs=['x'])
 
-        G1 = G.add_subsystem('G1', Group(), promotes_inputs=['x'], promotes_outputs=['y'])
+        G1 = G.add_subsystem('G1', om.Group(), promotes_inputs=['x'], promotes_outputs=['y'])
         G1.add_subsystem('C1_1', ObjAdderCompEx(_DiscreteVal(5)), promotes_inputs=['x'])
         G1.add_subsystem('C1_2', ObjAdderCompEx(_DiscreteVal(7)), promotes_outputs=['y'])
         G1.connect('C1_1.y', 'C1_2.x')
 
-        G2 = G.add_subsystem('G2', Group(), promotes_inputs=['x'])
+        G2 = G.add_subsystem('G2', om.Group(), promotes_inputs=['x'])
         G2.add_subsystem('C2_1', ObjAdderCompEx(_DiscreteVal(1)), promotes_inputs=['x'])
         G2.add_subsystem('C2_2', ObjAdderCompEx(_DiscreteVal(11)), promotes_outputs=['y'])
         G2.connect('C2_1.y', 'C2_2.x')
@@ -525,13 +597,45 @@ class DiscretePromTestCase(unittest.TestCase):
         self.assertEqual(prob['C3.y'].getval(), 40)
         self.assertEqual(prob['C4.y'].getval(), 52)
 
+        def _var_iter(obj):
+            name = obj['name']
+            if 'children' in obj:
+                for c in obj['children']:
+                    for vname in _var_iter(c):
+                        if name:
+                            yield '.'.join((name, vname))
+                        else:
+                            yield vname
+            else:
+                yield name
+
+        # add a test to see if discrete vars show up in view_model
+        data = _get_viewer_data(prob)
+        findvars = [
+            'indep.x',
+            'G.G1.C1_1.x',
+            'G.G1.C1_1.y',
+            'G.G1.C1_2.x',
+            'G.G1.C1_2.y',
+            'G.G2.C2_1.x',
+            'G.G2.C2_1.y',
+            'G.G2.C2_2.x',
+            'G.G2.C2_2.y',
+            'C3.x',
+            'C3.y',
+            'C4.x',
+            'C4.y',
+        ]
+        vnames = list(_var_iter(data['tree']))
+        self.assertTrue(sorted(findvars), sorted(vnames))
+
 
 class DiscreteFeatureTestCase(unittest.TestCase):
     def test_feature_discrete(self):
         import numpy as np
-        from openmdao.api import Problem, IndepVarComp, ExplicitComponent
+        import openmdao.api as om
 
-        class BladeSolidity(ExplicitComponent):
+        class BladeSolidity(om.ExplicitComponent):
             def setup(self):
 
                 # Continuous Inputs
@@ -553,8 +657,8 @@ class DiscreteFeatureTestCase(unittest.TestCase):
                 outputs['blade_solidity'] = chord / (2.0 * np.pi * r_m / num_blades)
 
         # build the model
-        prob = Problem()
-        indeps = prob.model.add_subsystem('indeps', IndepVarComp(), promotes=['*'])
+        prob = om.Problem()
+        indeps = prob.model.add_subsystem('indeps', om.IndepVarComp(), promotes=['*'])
         indeps.add_output('r_m', 3.2, units="ft")
         indeps.add_output('chord', .3, units='ft')
         indeps.add_discrete_output('num_blades', 2)
