@@ -85,7 +85,7 @@ class Test(unittest.TestCase):
         self.p = Problem(group)
 
         self.p.model.linear_solver = LinearBlockGS()
-        self.p.setup(check=False)
+        self.p.setup()
 
         # Conclude setup but don't run model.
         self.p.final_setup()
