@@ -2,6 +2,7 @@ import base64
 import json
 import os
 from collections import OrderedDict
+from itertools import chain
 
 import networkx as nx
 from six import iteritems, itervalues
@@ -20,6 +21,7 @@ from openmdao.core.indepvarcomp import IndepVarComp
 from openmdao.core.parallel_group import ParallelGroup
 from openmdao.core.group import Group
 from openmdao.core.problem import Problem
+from openmdao.core.component import Component
 from openmdao.core.implicitcomponent import ImplicitComponent
 from openmdao.devtools.html_utils import read_files, write_script, DiagramWriter
 from openmdao.utils.class_util import overrides_method
@@ -36,6 +38,27 @@ _MODEL_HEIGHTS = [600, 650, 700, 750, 800, 850, 900, 950, 1000, 2000, 3000, 4000
 _IND = 4  # HTML indentation (spaces)
 
 
+def _get_var_dict(system, typ, name):
+    if name in system._var_discrete[typ]:
+        meta = system._var_discrete[typ][name]
+    else:
+        meta = system._var_abs2meta[name]
+        name = system._var_abs2prom[typ][name]
+
+    var_dict = OrderedDict()
+    var_dict['name'] = name
+    if typ == 'input':
+        var_dict['type'] = 'param'
+    elif typ == 'output':
+        isimplicit = isinstance(system, ImplicitComponent)
+        var_dict['type'] = 'unknown'
+        var_dict['implicit'] = isimplicit
+
+    var_dict['dtype'] = type(meta['value']).__name__
+
+    return var_dict
+
+
 def _get_tree_dict(system, component_execution_orders, component_execution_index, is_parallel=False):
     """Get a dictionary representation of the system hierarchy."""
     tree_dict = OrderedDict()
@@ -63,21 +86,12 @@ def _get_tree_dict(system, component_execution_orders, component_execution_index
 
         children = []
         for typ in ['input', 'output']:
-            for ind, abs_name in enumerate(system._var_abs_names[typ]):
-                meta = system._var_abs2meta[abs_name]
-                name = system._var_abs2prom[typ][abs_name]
+            for abs_name in system._var_abs_names[typ]:
+                children.append(_get_var_dict(system, typ, abs_name))
 
-                var_dict = OrderedDict()
-                var_dict['name'] = name
-                if typ == 'input':
-                    var_dict['type'] = 'param'
-                elif typ == 'output':
-                    isimplicit = isinstance(system, ImplicitComponent)
-                    var_dict['type'] = 'unknown'
-                    var_dict['implicit'] = isimplicit
+            for prom_name in system._var_discrete[typ]:
+                children.append(_get_var_dict(system, typ, prom_name))
 
-                var_dict['dtype'] = type(meta['value']).__name__
-                children.append(var_dict)
     else:
         if isinstance(system, ParallelGroup):
             is_parallel = True
@@ -102,18 +116,17 @@ def _get_tree_dict(system, component_execution_orders, component_execution_index
             tree_dict['linear_solver'] = "solve_linear"
         else:
             tree_dict['linear_solver'] = ""
+
+        if overrides_method('solve_nonlinear', system, ImplicitComponent):
+            tree_dict['nonlinear_solver'] = "solve_nonlinear"
+        else:
+            tree_dict['nonlinear_solver'] = ""
     else:
         if system.linear_solver:
             tree_dict['linear_solver'] = system.linear_solver.SOLVER
         else:
             tree_dict['linear_solver'] = ""
 
-    if isinstance(system, ImplicitComponent):
-        if overrides_method('solve_nonlinear', system, ImplicitComponent):
-            tree_dict['nonlinear_solver'] = "solve_nonlinear"
-        else:
-            tree_dict['nonlinear_solver'] = ""
-    else:
         if system.nonlinear_solver:
             tree_dict['nonlinear_solver'] = system.nonlinear_solver.SOLVER
         else:
@@ -127,6 +140,38 @@ def _get_tree_dict(system, component_execution_orders, component_execution_index
 
     return tree_dict
 
+def _get_declare_partials(system):
+    """
+    Get a list of the declared partials.
+
+    Parameters
+    ----------
+    system : <System>
+        A System in the model.
+
+    Returns
+    -------
+    list
+        A list containing all the declared partials (strings in the form "of > wrt" )
+        beginning from the given system on down.
+    """
+
+    declare_partials_list = []
+
+    def recurse_get_partials(system, dpl):
+
+        if isinstance(system, Component):
+            subjacs = system._subjacs_info
+            for abs_key, meta in iteritems(subjacs):
+                dpl.append( "{} > {}".format(abs_key[0], abs_key[1]))
+        elif isinstance(system, Group):
+            for s in system._subsystems_myproc:
+                recurse_get_partials(s, dpl)
+        return
+
+    recurse_get_partials(system, declare_partials_list)
+    return declare_partials_list
+
 
 def _get_viewer_data(data_source):
     """
@@ -155,7 +200,7 @@ def _get_viewer_data(data_source):
         driver_options = {k: driver.options[k] for k in driver.options}
         driver_opt_settings = None
         if driver_type is 'optimization' and 'opt_settings' in dir(driver):
-            driver_opt_settings = driver.opt_settings   
+            driver_opt_settings = driver.opt_settings
 
     elif isinstance(data_source, Group):
         if not data_source.pathname:  # root group
@@ -176,78 +221,77 @@ def _get_viewer_data(data_source):
 
     data_dict = {}
     comp_exec_idx = [0]  # list so pass by ref
-    comp_exec_orders = {}
-    data_dict['tree'] = _get_tree_dict(root_group, comp_exec_orders, comp_exec_idx)
+    orders = {}
+    data_dict['tree'] = _get_tree_dict(root_group, orders, comp_exec_idx)
 
     connections_list = []
 
     sys_pathnames_list = []  # list of pathnames of systems found in cycles
     sys_pathnames_dict = {}  # map of pathnames to index of pathname in list
 
-    # sort to make deterministic for testing
-    sorted_abs_input2src = OrderedDict(sorted(root_group._conn_global_abs_in2out.items()))
-    root_group._conn_global_abs_in2out = sorted_abs_input2src
-
     G = root_group.compute_sys_graph(comps_only=True)
+
     scc = nx.strongly_connected_components(G)
-    scc_list = [s for s in scc if len(s) > 1]
 
-    for in_abs, out_abs in iteritems(sorted_abs_input2src):
-        if out_abs is None:
-            continue
+    seen = set()
+    for strong_comp in scc:
+        if len(strong_comp) > 1:
+            strongset = set(strong_comp)
+            sys_pathnames_list.extend(strong_comp)
+            for name in strong_comp:
+                sys_pathnames_dict[name] = len(sys_pathnames_dict)
 
-        src_subsystem = out_abs.rsplit('.', 1)[0]
-        tgt_subsystem = in_abs.rsplit('.', 1)[0]
-        src_to_tgt_str = src_subsystem + ' ' + tgt_subsystem
+            edge_orders = [(u, orders[u], v, orders[v]) for u, v in G.edges(strong_comp)
+                           if u in strongset and v in strongset]
 
-        count = 0
-        edges_list = []
+            for src, exe_src, tgt, exe_tgt in edge_orders:
+                if exe_tgt < exe_src:
+                    exe_low = exe_tgt
+                    exe_high = exe_src
+                else:
+                    exe_low = exe_src
+                    exe_high = exe_tgt
 
-        for li in scc_list:
-            if src_subsystem in li and tgt_subsystem in li:
-                count += 1
-                if count > 1:
-                    raise ValueError('Count greater than 1')
+                edges_list = [(sys_pathnames_dict[s], sys_pathnames_dict[t])
+                              for s, order_s, t, order_t in edge_orders
+                              if exe_low <= order_s <= exe_high
+                              and exe_low <= order_t <= exe_high and not (s == src and t == tgt)]
 
-                exe_tgt = comp_exec_orders[tgt_subsystem]
-                exe_src = comp_exec_orders[src_subsystem]
-                exe_low = min(exe_tgt, exe_src)
-                exe_high = max(exe_tgt, exe_src)
-
-                subg = G.subgraph(n for n in li if exe_low <= comp_exec_orders[n] <= exe_high)
-                for edge in subg.edges():
-                    edge_str = ' '.join(edge)
-                    if edge_str != src_to_tgt_str:
-                        src, tgt = edge
-
-                        # add src & tgt to pathnames list & dict if not already there
-                        for pathname in edge:
-                            if pathname not in sys_pathnames_dict:
-                                sys_pathnames_list.append(pathname)
-                                sys_pathnames_dict[pathname] = len(sys_pathnames_list) - 1
-
-                        # replace src & tgt pathnames with indices into pathname list
-                        src = sys_pathnames_dict[src]
-                        tgt = sys_pathnames_dict[tgt]
-
-                        edges_list.append([src, tgt])
-
-        if edges_list:
-            edges_list.sort()  # make deterministic so same .html file will be produced each run
-            connections_list.append(dict([('src', out_abs), ('tgt', in_abs),
-                                          ('cycle_arrows', edges_list)]))
+                if edges_list:
+                    for vsrc, vtgtlist in iteritems(G.get_edge_data(src, tgt)['conns']):
+                        for vtgt in vtgtlist:
+                            conn = (vsrc, vtgt)
+                            if conn not in seen:
+                                connections_list.append({'src': vsrc, 'tgt': vtgt,
+                                                         'cycle_arrows': edges_list})
+                                seen.add(conn)
+                else:
+                    for vsrc, vtgtlist in iteritems(G.get_edge_data(src, tgt)['conns']):
+                        for vtgt in vtgtlist:
+                            conn = (vsrc, vtgt)
+                            if conn not in seen:
+                                connections_list.append({'src': vsrc, 'tgt': vtgt})
+                                seen.add(conn)
         else:
-            connections_list.append(dict([('src', out_abs), ('tgt', in_abs)]))
+            for edge in chain(G.edges(strong_comp), G.in_edges(strong_comp)):
+                for vsrc, vtgtlist in iteritems(G.get_edge_data(edge[0], edge[1])['conns']):
+                    for vtgt in vtgtlist:
+                        conn = (vsrc, vtgt)
+                        if conn not in seen:
+                            connections_list.append({'src': vsrc, 'tgt': vtgt})
+                            seen.add(conn)
 
     data_dict['sys_pathnames_list'] = sys_pathnames_list
     data_dict['connections_list'] = connections_list
     data_dict['abs2prom'] = root_group._var_abs2prom
 
-    data_dict['driver'] = {'name': driver_name, 'type': driver_type, 
-                           'options': driver_options, 'opt_settings': driver_opt_settings} 
+    data_dict['driver'] = {'name': driver_name, 'type': driver_type,
+                           'options': driver_options, 'opt_settings': driver_opt_settings}
     data_dict['design_vars'] = root_group.get_design_vars()
     data_dict['responses'] = root_group.get_responses()
 
+    data_dict['declare_partials_list'] = _get_declare_partials(root_group)
+
     return data_dict
 
 
@@ -260,7 +304,7 @@ def view_tree(*args, **kwargs):
 
 
 def view_model(data_source, outfile='n2.html', show_browser=True, embeddable=False,
-               title=None):
+               title=None, use_declare_partial_info=False):
     """
     Generates an HTML file containing a tree viewer.
 
@@ -285,9 +329,18 @@ def view_model(data_source, outfile='n2.html', show_browser=True, embeddable=Fal
     title : str, optional
         The title for the diagram. Used in the HTML title and also shown on the page.
 
+    use_declare_partial_info: bool, optional
+        If True, in the N2 matrix, component internal connectivity computed using derivative
+        declarations, otherwise, derivative declarations ignored, so dense component connectivity
+        is assumed.
+
     """
     # grab the model viewer data
     model_data = _get_viewer_data(data_source)
+    options = {}
+    options['use_declare_partial_info'] = use_declare_partial_info
+    model_data['options'] = options
+
     model_data = 'var modelData = %s' % json.dumps(model_data, default=make_serializable)
 
     # if MPI is active only display one copy of the viewer
@@ -355,7 +408,6 @@ def view_model(data_source, outfile='n2.html', show_browser=True, embeddable=Fal
                       content="icon-eraser")
     group3.add_button("Show Path", uid="showCurrentPathButtonId", content="icon-terminal")
     group3.add_button("Show Legend", uid="showLegendButtonId", content="icon-map-signs")
-    group3.add_button("Show Params", uid="showParamsButtonId", content="icon-exchange")
     group3.add_button("Toggle Solver Names", uid="toggleSolverNamesButtonId", content="icon-minus")
     group3.add_dropdown("Font Size", id_naming="idFontSize", options=_FONT_SIZES,
                         option_formatter=lambda x: '{}px'.format(x),
@@ -377,6 +429,13 @@ def view_model(data_source, outfile='n2.html', show_browser=True, embeddable=Fal
 
     h.add_help(help_txt, footer="OpenMDAO Model Hierarchy and N^2 diagram")
 
+    if use_declare_partial_info:
+        h.insert( '{{component_connectivity}}',
+                  'Note: Component internal connectivity computed using derivative declarations')
+    else:
+        h.insert( '{{component_connectivity}}',
+                  'Note: Derivative declarations ignored, so dense component connectivity is assumed')
+
     # Write output file
     h.write(outfile)
 
