@@ -20,6 +20,7 @@ from six.moves import range, zip, cStringIO as cStringIO
 
 from sphinx.errors import SphinxError
 from sphinx.writers.html import HTMLTranslator
+from sphinx.writers.html5 import HTML5Translator
 from redbaron import RedBaron
 
 if sys.version_info[0] == 2:
@@ -44,7 +45,7 @@ def visit_skipped_or_failed_node(self, node):
 
 
 def depart_skipped_or_failed_node(self, node):
-    if not isinstance(self, HTMLTranslator):
+    if not isinstance(self, (HTMLTranslator, HTML5Translator)):
         self.body.append("output only available for HTML\n")
         return
 
@@ -65,7 +66,7 @@ def depart_in_or_out_node(self, node):
     This function creates the formatting that sets up the look of the blocks.
     The look of the formatting is controlled by _theme/static/style.css
     """
-    if not isinstance(self, HTMLTranslator):
+    if not isinstance(self, (HTMLTranslator, HTML5Translator)):
         self.body.append("output only available for HTML\n")
         return
     if node["kind"] == "In":
@@ -629,7 +630,7 @@ def sync_multi_output_blocks(blocks):
         return []
 
 
-def run_code(code_to_run, path, module=None, cls=None, shows_plot=False):
+def run_code(code_to_run, path, module=None, cls=None, shows_plot=False, imports_not_required=False):
     """
     Run the given code chunk and collect the output.
     """
@@ -730,7 +731,12 @@ def run_code(code_to_run, path, module=None, cls=None, shows_plot=False):
                         '__cached__': None,
                     }
                 else:
-                    globals_dict = module.__dict__
+                    if imports_not_required:
+                        # code does not need to include all imports
+                        # Get from module
+                        globals_dict = module.__dict__
+                    else:
+                        globals_dict = {}
 
                 try:
                     exec(code_to_run, globals_dict)
