@@ -240,6 +240,8 @@ class ScipyOptimizeDriver(Driver):
         self.iter_count = 0
         self._total_jac = None
 
+        self._check_for_missing_objective()
+
         # Initial Run
         with RecordingDebugging(self._get_name(), self.iter_count, self) as rec:
             model.run_solve_nonlinear()
@@ -413,7 +415,7 @@ class ScipyOptimizeDriver(Driver):
             hess = None
 
         # compute dynamic simul deriv coloring if option is set
-        if coloring_mod._use_sparsity:
+        if coloring_mod._use_total_sparsity:
             if self._coloring_info['coloring'] is coloring_mod._DYN_COLORING:
                 coloring_mod.dynamic_total_coloring(self, run_model=False,
                                                     fname=self._get_total_coloring_fname())
