@@ -31,7 +31,7 @@ elif PY3:
 _coord_system_re = re.compile('(_solve_nonlinear|_apply_nonlinear)$')
 
 # Regular expression used for splitting iteration coordinates, removes separator and iter counts
-_coord_split_re = re.compile('\|\\d+\|*')
+_coord_split_re = re.compile('\\|\\d+\\|*')
 
 
 def _get_source_system(iteration_coordinate):
@@ -414,9 +414,9 @@ class SqliteCaseReader(BaseCaseReader):
             raise RuntimeError('No cases recorded for %s' % source)
 
         if case.inputs:
-            dct['inputs'] = list(case.inputs.keys())
+            dct['inputs'] = list(case.inputs)
         if case.outputs:
-            dct['outputs'] = list(case.outputs.keys())
+            dct['outputs'] = list(case.outputs)
 
         return dct
 
