@@ -15,7 +15,7 @@ class LinearBlockGS(BlockLinearSolver):
 
     SOLVER = 'LN: LNBGS'
 
-    def _iter_execute(self):
+    def _single_iteration(self):
         """
         Perform the operations in the iteration loop.
         """
