@@ -24,33 +24,15 @@ class LinearRunOnce(LinearBlockGS):
             'fwd' or 'rev'.
         rel_systems : set of str
             Names of systems relevant to the current solve.
-
-        Returns
-        -------
-        float
-            Initial error.
-        float
-            Error at the first iteration.
         """
         self._vec_names = vec_names
         self._mode = mode
         self._rel_systems = rel_systems
-        system = self._system
 
-        # Pre-processing
-        if self._mode == 'fwd':
-            b_vecs = system._vectors['residual']
-        else:  # rev
-            b_vecs = system._vectors['output']
-
-        for vec_name in self._vec_names:
-            if vec_name in system._rel_vec_names:
-                self._rhs_vecs[vec_name][:] = b_vecs[vec_name]._data
+        self._update_rhs_vecs()
 
         # Single iteration of GS
-        self._iter_execute()
-
-        return False, 0.0, 0.0
+        self._single_iteration()
 
     def _declare_options(self):
         """
