@@ -5,17 +5,16 @@ import unittest
 
 import numpy as np
 
+import openmdao.api as om
 from openmdao.solvers.linear.tests.linear_test_base import LinearSolverTests
-from openmdao.utils.assert_utils import assert_rel_error
-from openmdao.api import LinearBlockGS, Problem, Group, ImplicitComponent, IndepVarComp, \
-    DirectSolver, NewtonSolver, ScipyKrylov, ExecComp, NonlinearBlockGS, BoundsEnforceLS
 from openmdao.test_suite.components.sellar import SellarImplicitDis1, SellarImplicitDis2, \
     SellarDis1withDerivatives, SellarDis2withDerivatives
 from openmdao.test_suite.components.expl_comp_simple import TestExplCompSimpleDense
 from openmdao.test_suite.components.sellar import SellarDerivatives
+from openmdao.utils.assert_utils import assert_rel_error
 
 
-class SimpleImp(ImplicitComponent):
+class SimpleImp(om.ImplicitComponent):
     def setup(self):
         self.add_input('a', val=1.)
         self.add_output('x', val=0.)
@@ -31,18 +30,18 @@ class SimpleImp(ImplicitComponent):
 
 
 class TestBGSSolver(LinearSolverTests.LinearSolverTestCase):
-    linear_solver_class = LinearBlockGS
+    linear_solver_class = om.LinearBlockGS
 
     def test_globaljac_err(self):
-        prob = Problem()
-        model = prob.model = Group(assembled_jac_type='dense')
-        model.add_subsystem('x_param', IndepVarComp('length', 3.0),
+        prob = om.Problem()
+        model = prob.model = om.Group(assembled_jac_type='dense')
+        model.add_subsystem('x_param', om.IndepVarComp('length', 3.0),
                             promotes=['length'])
         model.add_subsystem('mycomp', TestExplCompSimpleDense(),
                             promotes=['length', 'width', 'area'])
 
         model.linear_solver = self.linear_solver_class(assemble_jac=True)
-        prob.setup(check=False)
+        prob.setup()
 
         with self.assertRaises(RuntimeError) as context:
             prob.run_model()
@@ -54,14 +53,14 @@ class TestBGSSolver(LinearSolverTests.LinearSolverTestCase):
         # This verifies that we can perform lgs around an implicit comp and get the right answer
         # as long as we slot a non-lgs linear solver on that component.
 
-        prob = Problem()
-        model = prob.model = Group()
-        model.add_subsystem('p', IndepVarComp('a', 5.0))
+        prob = om.Problem()
+        model = prob.model
+        model.add_subsystem('p', om.IndepVarComp('a', 5.0))
         comp = model.add_subsystem('comp', SimpleImp())
         model.connect('p.a', 'comp.a')
 
         model.linear_solver = self.linear_solver_class()
-        comp.linear_solver = DirectSolver()
+        comp.linear_solver = om.DirectSolver()
 
         prob.setup(check=False, mode='fwd')
         prob.run_model()
@@ -70,20 +69,20 @@ class TestBGSSolver(LinearSolverTests.LinearSolverTestCase):
         self.assertEqual(deriv['comp.x', 'p.a'], -1.5)
 
     def test_implicit_cycle(self):
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('p1', IndepVarComp('x', 1.0))
+        model.add_subsystem('p1', om.IndepVarComp('x', 1.0))
         model.add_subsystem('d1', SellarImplicitDis1())
         model.add_subsystem('d2', SellarImplicitDis2())
         model.connect('d1.y1', 'd2.y1')
         model.connect('d2.y2', 'd1.y2')
 
-        model.nonlinear_solver = NewtonSolver()
+        model.nonlinear_solver = om.NewtonSolver()
         model.nonlinear_solver.options['maxiter'] = 5
         model.linear_solver = self.linear_solver_class()
 
-        prob.setup(check=False)
+        prob.setup()
         prob.set_solver_print(level=0)
 
         prob.run_model()
@@ -93,22 +92,22 @@ class TestBGSSolver(LinearSolverTests.LinearSolverTestCase):
         self.assertLess(res, 2.0e-2)
 
     def test_implicit_cycle_precon(self):
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('p1', IndepVarComp('x', 1.0))
+        model.add_subsystem('p1', om.IndepVarComp('x', 1.0))
         model.add_subsystem('d1', SellarImplicitDis1())
         model.add_subsystem('d2', SellarImplicitDis2())
         model.connect('d1.y1', 'd2.y1')
         model.connect('d2.y2', 'd1.y2')
 
-        model.nonlinear_solver = NewtonSolver()
+        model.nonlinear_solver = om.NewtonSolver()
         model.nonlinear_solver.options['maxiter'] = 5
-        model.nonlinear_solver.linesearch = BoundsEnforceLS()
-        model.linear_solver = ScipyKrylov()
+        model.nonlinear_solver.linesearch = om.BoundsEnforceLS()
+        model.linear_solver = om.ScipyKrylov()
         model.linear_solver.precon = self.linear_solver_class()
 
-        prob.setup(check=False)
+        prob.setup()
 
         prob['d1.y1'] = 4.0
         prob.set_solver_print()
@@ -119,19 +118,19 @@ class TestBGSSolver(LinearSolverTests.LinearSolverTestCase):
         self.assertLess(res, 2.0e-2)
 
     def test_full_desvar_with_index_obj_relevance_bug(self):
-        prob = Problem()
+        prob = om.Problem()
         sub = prob.model.add_subsystem('sub', SellarDerivatives())
-        prob.model.nonlinear_solver = NonlinearBlockGS()
-        prob.model.linear_solver = LinearBlockGS()
-        sub.nonlinear_solver = NonlinearBlockGS()
-        sub.linear_solver = LinearBlockGS()
+        prob.model.nonlinear_solver = om.NonlinearBlockGS()
+        prob.model.linear_solver = om.LinearBlockGS()
+        sub.nonlinear_solver = om.NonlinearBlockGS()
+        sub.linear_solver = om.LinearBlockGS()
 
         prob.model.add_design_var('sub.z', lower=-100, upper=100)
         prob.model.add_objective('sub.z', index=1)
 
         prob.set_solver_print(level=0)
 
-        prob.setup(check=False)
+        prob.setup()
 
         # We don't call run_driver() here because we don't
         # actually want the optimizer to run
@@ -147,27 +146,27 @@ class TestBGSSolverFeature(unittest.TestCase):
     def test_specify_solver(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, ExecComp, LinearBlockGS, NonlinearBlockGS
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, SellarDis2withDerivatives
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.linear_solver = LinearBlockGS()
-        model.nonlinear_solver = NonlinearBlockGS()
+        model.linear_solver = om.LinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
 
         prob.setup()
         prob.run_model()
@@ -182,28 +181,28 @@ class TestBGSSolverFeature(unittest.TestCase):
     def test_feature_maxiter(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, ExecComp, LinearBlockGS, NonlinearBlockGS
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, SellarDis2withDerivatives
 
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
 
-        model.linear_solver = LinearBlockGS()
+        model.linear_solver = om.LinearBlockGS()
         model.linear_solver.options['maxiter'] = 2
 
         prob.setup()
@@ -219,28 +218,28 @@ class TestBGSSolverFeature(unittest.TestCase):
     def test_feature_atol(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, ExecComp, LinearBlockGS, NonlinearBlockGS
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, SellarDis2withDerivatives
 
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
 
-        model.linear_solver = LinearBlockGS()
+        model.linear_solver = om.LinearBlockGS()
         model.linear_solver.options['atol'] = 1.0e-3
 
         prob.setup()
@@ -256,28 +255,28 @@ class TestBGSSolverFeature(unittest.TestCase):
     def test_feature_rtol(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, ExecComp, LinearBlockGS, NonlinearBlockGS
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, SellarDis2withDerivatives
 
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
 
-        model.linear_solver = LinearBlockGS()
+        model.linear_solver = om.LinearBlockGS()
         model.linear_solver.options['rtol'] = 1.0e-3
 
         prob.setup()
