@@ -6,8 +6,7 @@ import unittest
 
 import numpy as np
 
-from openmdao.api import Problem, Group, IndepVarComp, PETScKrylov, LinearBlockGS, DirectSolver, \
-     ExecComp, NewtonSolver, NonlinearBlockGS, PetscKSP
+import openmdao.api as om
 from openmdao.test_suite.components.expl_comp_simple import TestExplCompSimpleDense
 from openmdao.test_suite.components.misc_components import Comp4LinearCacheTest
 from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, SellarDis2withDerivatives
@@ -28,8 +27,8 @@ class TestPETScKrylov(unittest.TestCase):
     def test_options(self):
         """Verify that the PETScKrylov specific options are declared."""
 
-        group = Group()
-        group.linear_solver = PETScKrylov()
+        group = om.Group()
+        group.linear_solver = om.PETScKrylov()
 
         assert(group.linear_solver.options['ksp_type'] == 'fgmres')
 
@@ -41,10 +40,10 @@ class TestPETScKrylov(unittest.TestCase):
         msg = "PetscKSP is deprecated.  Use PETScKrylov instead."
 
         with assert_warning(DeprecationWarning, msg):
-            group = TestImplicitGroup(lnSolverClass=PetscKSP)
+            group = TestImplicitGroup(lnSolverClass=om.PetscKSP)
 
-        p = Problem(group)
-        p.setup(check=False)
+        p = om.Problem(group)
+        p.setup()
         p.set_solver_print(level=0)
 
         # Conclude setup but don't run model.
@@ -71,11 +70,11 @@ class TestPETScKrylov(unittest.TestCase):
     def test_solve_linear_ksp_gmres(self):
         """Solve implicit system with PETScKrylov using 'gmres' method."""
 
-        group = TestImplicitGroup(lnSolverClass=PETScKrylov)
+        group = TestImplicitGroup(lnSolverClass=om.PETScKrylov)
         group.linear_solver.options['ksp_type'] = 'gmres'
 
-        p = Problem(group)
-        p.setup(check=False)
+        p = om.Problem(group)
+        p.setup()
         p.set_solver_print(level=0)
 
         # Conclude setup but don't run model.
@@ -102,11 +101,11 @@ class TestPETScKrylov(unittest.TestCase):
     def test_solve_linear_ksp_maxiter(self):
         """Verify that PETScKrylov abides by the 'maxiter' option."""
 
-        group = TestImplicitGroup(lnSolverClass=PETScKrylov)
+        group = TestImplicitGroup(lnSolverClass=om.PETScKrylov)
         group.linear_solver.options['maxiter'] = 2
 
-        p = Problem(group)
-        p.setup(check=False)
+        p = om.Problem(group)
+        p.setup()
         p.set_solver_print(level=0)
 
         # Conclude setup but don't run model.
@@ -131,11 +130,11 @@ class TestPETScKrylov(unittest.TestCase):
     def test_solve_linear_ksp_precon(self):
         """Solve implicit system with PETScKrylov using a preconditioner."""
 
-        group = TestImplicitGroup(lnSolverClass=PETScKrylov)
-        precon = group.linear_solver.precon = LinearBlockGS()
+        group = TestImplicitGroup(lnSolverClass=om.PETScKrylov)
+        precon = group.linear_solver.precon = om.LinearBlockGS()
 
-        p = Problem(group)
-        p.setup(check=False)
+        p = om.Problem(group)
+        p.setup()
         p.set_solver_print(level=0)
 
         # Conclude setup but don't run model.
@@ -164,8 +163,8 @@ class TestPETScKrylov(unittest.TestCase):
         self.assertTrue(precon._iter_count > 0)
 
         # test the direct solver and make sure KSP correctly recurses for _linearize
-        precon = group.linear_solver.precon = DirectSolver(assemble_jac=False)
-        p.setup(check=False)
+        precon = group.linear_solver.precon = om.DirectSolver(assemble_jac=False)
+        p.setup()
 
         # Conclude setup but don't run model.
         p.final_setup()
@@ -193,13 +192,13 @@ class TestPETScKrylov(unittest.TestCase):
     def test_solve_linear_ksp_precon_left(self):
         """Solve implicit system with PETScKrylov using a preconditioner."""
 
-        group = TestImplicitGroup(lnSolverClass=PETScKrylov)
-        precon = group.linear_solver.precon = DirectSolver(assemble_jac=False)
+        group = TestImplicitGroup(lnSolverClass=om.PETScKrylov)
+        precon = group.linear_solver.precon = om.DirectSolver(assemble_jac=False)
         group.linear_solver.options['precon_side'] = 'left'
         group.linear_solver.options['ksp_type'] = 'richardson'
 
-        p = Problem(group)
-        p.setup(check=False)
+        p = om.Problem(group)
+        p.setup()
         p.set_solver_print(level=0)
 
         # Conclude setup but don't run model.
@@ -226,11 +225,11 @@ class TestPETScKrylov(unittest.TestCase):
         assert_rel_error(self, output, group.expected_solution, 3e-15)
 
         # test the direct solver and make sure KSP correctly recurses for _linearize
-        precon = group.linear_solver.precon = DirectSolver(assemble_jac=False)
+        precon = group.linear_solver.precon = om.DirectSolver(assemble_jac=False)
         group.linear_solver.options['precon_side'] = 'left'
         group.linear_solver.options['ksp_type'] = 'richardson'
 
-        p.setup(check=False)
+        p.setup()
 
         # Conclude setup but don't run model.
         p.final_setup()
@@ -257,14 +256,14 @@ class TestPETScKrylov(unittest.TestCase):
 
     def test_preconditioner_deprecation(self):
 
-        group = TestImplicitGroup(lnSolverClass=PETScKrylov)
+        group = TestImplicitGroup(lnSolverClass=om.PETScKrylov)
 
         msg = "The 'preconditioner' property provides backwards compatibility " \
               "with OpenMDAO <= 1.x ; use 'precon' instead."
 
         # check deprecation on setter & getter
         with assert_warning(DeprecationWarning, msg):
-            precon = group.linear_solver.preconditioner = LinearBlockGS()
+            precon = group.linear_solver.preconditioner = om.LinearBlockGS()
 
         with assert_warning(DeprecationWarning, msg):
             pre = group.linear_solver.preconditioner
@@ -272,16 +271,16 @@ class TestPETScKrylov(unittest.TestCase):
     def test_solve_on_subsystem(self):
         """solve an implicit system with KSP attached anywhere but the root"""
 
-        p = Problem()
+        p = om.Problem()
         model = p.model
 
-        dv = model.add_subsystem('des_vars', IndepVarComp())
+        dv = model.add_subsystem('des_vars', om.IndepVarComp())
         # just need a dummy variable so the sizes don't match between root and g1
         dv.add_output('dummy', val=1.0, shape=10)
 
-        g1 = model.add_subsystem('g1', TestImplicitGroup(lnSolverClass=PETScKrylov))
+        g1 = model.add_subsystem('g1', TestImplicitGroup(lnSolverClass=om.PETScKrylov))
 
-        p.setup(check=False)
+        p.setup()
 
         p.set_solver_print(level=0)
 
@@ -315,14 +314,14 @@ class TestPETScKrylov(unittest.TestCase):
 
         # Forward mode
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
         model.add_subsystem('d1', Comp4LinearCacheTest(), promotes=['x', 'y'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
-        model.linear_solver = PETScKrylov()
+        model.nonlinear_solver = om.NonlinearBlockGS()
+        model.linear_solver = om.PETScKrylov()
 
         model.add_design_var('x', cache_linear_solution=True)
         model.add_objective('y', cache_linear_solution=True)
@@ -343,14 +342,14 @@ class TestPETScKrylov(unittest.TestCase):
 
         # Reverse mode
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
         model.add_subsystem('d1', Comp4LinearCacheTest(), promotes=['x', 'y'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
-        model.linear_solver = PETScKrylov()
+        model.nonlinear_solver = om.NonlinearBlockGS()
+        model.linear_solver = om.PETScKrylov()
 
         model.add_design_var('x', cache_linear_solution=True)
         model.add_objective('y', cache_linear_solution=True)
@@ -371,24 +370,24 @@ class TestPETScKrylov(unittest.TestCase):
 
     def test_error_under_cs(self):
         """Verify that PETScKrylov abides by the 'maxiter' option."""
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NewtonSolver()
-        model.linear_solver = PETScKrylov()
+        model.nonlinear_solver = om.NewtonSolver()
+        model.linear_solver = om.PETScKrylov()
 
         model.approx_totals(method='cs')
 
@@ -409,28 +408,28 @@ class TestPETScKrylovSolverFeature(unittest.TestCase):
     def test_specify_solver(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, NonlinearBlockGS, PETScKrylov, ExecComp
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, SellarDis2withDerivatives
 
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
 
-        model.linear_solver = PETScKrylov()
+        model.linear_solver = om.PETScKrylov()
 
         prob.setup()
         prob.run_model()
@@ -445,30 +444,29 @@ class TestPETScKrylovSolverFeature(unittest.TestCase):
     def test_specify_ksp_type(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, NonlinearBlockGS, PETScKrylov, \
-             ExecComp
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, \
              SellarDis2withDerivatives
 
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
 
-        model.linear_solver = PETScKrylov()
+        model.linear_solver = om.PETScKrylov()
         model.linear_solver.options['ksp_type'] = 'gmres'
 
         prob.setup()
@@ -484,28 +482,28 @@ class TestPETScKrylovSolverFeature(unittest.TestCase):
     def test_feature_maxiter(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, NonlinearBlockGS, PETScKrylov, ExecComp
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, SellarDis2withDerivatives
 
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
 
-        model.linear_solver = PETScKrylov()
+        model.linear_solver = om.PETScKrylov()
         model.linear_solver.options['maxiter'] = 3
 
         prob.setup()
@@ -521,28 +519,28 @@ class TestPETScKrylovSolverFeature(unittest.TestCase):
     def test_feature_atol(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, NonlinearBlockGS, PETScKrylov, ExecComp
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, SellarDis2withDerivatives
 
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
 
-        model.linear_solver = PETScKrylov()
+        model.linear_solver = om.PETScKrylov()
         model.linear_solver.options['atol'] = 1.0e-20
 
         prob.setup()
@@ -558,28 +556,28 @@ class TestPETScKrylovSolverFeature(unittest.TestCase):
     def test_feature_rtol(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, NonlinearBlockGS, PETScKrylov, ExecComp
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, SellarDis2withDerivatives
 
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NonlinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
 
-        model.linear_solver = PETScKrylov()
+        model.linear_solver = om.PETScKrylov()
         model.linear_solver.options['rtol'] = 1.0e-20
 
         prob.setup()
@@ -595,31 +593,30 @@ class TestPETScKrylovSolverFeature(unittest.TestCase):
     def test_specify_precon(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, LinearBlockGS, PETScKrylov, \
-             NewtonSolver, ExecComp
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, \
              SellarDis2withDerivatives
 
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NewtonSolver()
-        model.linear_solver = PETScKrylov()
+        model.nonlinear_solver = om.NewtonSolver()
+        model.linear_solver = om.PETScKrylov()
 
-        model.linear_solver.precon = LinearBlockGS()
+        model.linear_solver.precon = om.LinearBlockGS()
         model.linear_solver.precon.options['maxiter'] = 2
 
         prob.setup()
@@ -631,31 +628,30 @@ class TestPETScKrylovSolverFeature(unittest.TestCase):
     def test_specify_precon_left(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, DirectSolver, PETScKrylov, \
-             NewtonSolver, ExecComp
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, \
              SellarDis2withDerivatives
 
-        prob = Problem()
-        model = prob.model = Group()
+        prob = om.Problem()
+        model = prob.model
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         model.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         model.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                z=np.array([0.0, 0.0]), x=0.0),
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+                                                   z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        model.nonlinear_solver = NewtonSolver()
-        model.linear_solver = PETScKrylov()
+        model.nonlinear_solver = om.NewtonSolver()
+        model.linear_solver = om.PETScKrylov()
 
-        model.linear_solver.precon = DirectSolver()
+        model.linear_solver.precon = om.DirectSolver()
         model.linear_solver.options['precon_side'] = 'left'
         model.linear_solver.options['ksp_type'] = 'richardson'
 
