@@ -33,7 +33,7 @@ class NonlinearRunOnce(NonlinearSolver):
                     for subsys in system._subsystems_myproc:
                         subsys._solve_nonlinear()
 
-                system._check_reconf_update()
+                system._check_child_reconf()
 
             # If this is not a parallel group, transfer for each subsystem just prior to running it.
             else:
