@@ -2,21 +2,18 @@
 from __future__ import print_function
 
 from six import iteritems
-
 import unittest
 
 import numpy as np
 
-from openmdao.api import Problem, LinearRunOnce, ImplicitComponent, IndepVarComp, DirectSolver, \
-     BoundsEnforceLS, LinearBlockGS, Group, ExecComp
-from openmdao.solvers.nonlinear.broyden import BroydenSolver
+import openmdao.api as om
 from openmdao.test_suite.components.implicit_newton_linesearch import ImplCompTwoStates
 from openmdao.test_suite.components.sellar import SellarStateConnection, SellarDerivatives, \
      SellarDis1withDerivatives, SellarDis2withDerivatives
 from openmdao.utils.assert_utils import assert_rel_error, assert_warning
 
 
-class VectorEquation(ImplicitComponent):
+class VectorEquation(om.ImplicitComponent):
     """Equation with 5 states in a single vector. Should converge to x=[0,0,0,0,0]"""
 
     def setup(self):
@@ -32,7 +29,7 @@ class VectorEquation(ImplicitComponent):
         residuals['x'] = -d*x - c*x**3
 
 
-class MixedEquation(ImplicitComponent):
+class MixedEquation(om.ImplicitComponent):
     """Equation with 5 states split between 3 vars. Should converge to x=[0,0,0,0,0]"""
 
     def setup(self):
@@ -75,7 +72,7 @@ class MixedEquation(ImplicitComponent):
         jacobian['x45', 'c'] = -3.0 * x45**2
 
 
-class SpedicatoHuang(ImplicitComponent):
+class SpedicatoHuang(om.ImplicitComponent):
 
     cite = """
            @article{spedicato_hwang,
@@ -130,11 +127,11 @@ class TestBryoden(unittest.TestCase):
     def test_error_badname(self):
         # Test top level Sellar (i.e., not grouped).
 
-        prob = Problem()
-        model = prob.model = SellarStateConnection(nonlinear_solver=BroydenSolver(),
-                                                   linear_solver=LinearRunOnce())
+        prob = om.Problem()
+        model = prob.model = SellarStateConnection(nonlinear_solver=om.BroydenSolver(),
+                                                   linear_solver=om.LinearRunOnce())
 
-        prob.setup(check=False)
+        prob.setup()
 
         model.nonlinear_solver.options['state_vars'] = ['junk']
 
@@ -147,11 +144,11 @@ class TestBryoden(unittest.TestCase):
     def test_error_need_direct_solver(self):
         # Test top level Sellar (i.e., not grouped).
 
-        prob = Problem()
-        model = prob.model = SellarStateConnection(nonlinear_solver=BroydenSolver(),
-                                                   linear_solver=LinearRunOnce())
+        prob = om.Problem()
+        model = prob.model = SellarStateConnection(nonlinear_solver=om.BroydenSolver(),
+                                                   linear_solver=om.LinearRunOnce())
 
-        prob.setup(check=False)
+        prob.setup()
 
         with self.assertRaises(ValueError) as context:
             prob.run_model()
@@ -162,11 +159,11 @@ class TestBryoden(unittest.TestCase):
     def test_simple_sellar(self):
         # Test top level Sellar (i.e., not grouped).
 
-        prob = Problem()
-        model = prob.model = SellarStateConnection(nonlinear_solver=BroydenSolver(),
-                                                   linear_solver=LinearRunOnce())
+        prob = om.Problem()
+        model = prob.model = SellarStateConnection(nonlinear_solver=om.BroydenSolver(),
+                                                   linear_solver=om.LinearRunOnce())
 
-        prob.setup(check=False)
+        prob.setup()
 
         model.nonlinear_solver.options['state_vars'] = ['state_eq.y2_command']
         model.nonlinear_solver.options['compute_jacobian'] = False
@@ -179,11 +176,11 @@ class TestBryoden(unittest.TestCase):
     def test_simple_sellar_cycle(self):
         # Test top level Sellar (i.e., not grouped).
 
-        prob = Problem()
-        model = prob.model = SellarDerivatives(nonlinear_solver=BroydenSolver(),
-                                               linear_solver=LinearRunOnce())
+        prob = om.Problem()
+        model = prob.model = SellarDerivatives(nonlinear_solver=om.BroydenSolver(),
+                                               linear_solver=om.LinearRunOnce())
 
-        prob.setup(check=False)
+        prob.setup()
 
         model.nonlinear_solver.options['state_vars'] = ['y1']
         model.nonlinear_solver.options['compute_jacobian'] = True
@@ -198,12 +195,12 @@ class TestBryoden(unittest.TestCase):
     def test_sellar_state_connection_fd_system(self):
         # Sellar model closes loop with state connection instead of a cycle.
         # This test is just fd.
-        prob = Problem()
-        model = prob.model = SellarStateConnection(nonlinear_solver=BroydenSolver(),
-                                                   linear_solver=LinearRunOnce())
+        prob = om.Problem()
+        model = prob.model = SellarStateConnection(nonlinear_solver=om.BroydenSolver(),
+                                                   linear_solver=om.LinearRunOnce())
         prob.model.approx_totals(method='fd')
 
-        prob.setup(check=False)
+        prob.setup()
 
         model.nonlinear_solver.options['state_vars'] = ['state_eq.y2_command']
         model.nonlinear_solver.options['compute_jacobian'] = False
@@ -219,20 +216,20 @@ class TestBryoden(unittest.TestCase):
     def test_vector(self):
         # Testing Broyden on a 5 state single vector case.
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', IndepVarComp('c', 0.01))
+        model.add_subsystem('p1', om.IndepVarComp('c', 0.01))
         model.add_subsystem('vec', VectorEquation())
 
         model.connect('p1.c', 'vec.c')
 
-        model.nonlinear_solver = BroydenSolver()
+        model.nonlinear_solver = om.BroydenSolver()
         model.nonlinear_solver.options['state_vars'] = ['vec.x']
         model.nonlinear_solver.options['maxiter'] = 15
         model.nonlinear_solver.options['compute_jacobian'] = False
 
-        prob.setup(check=False)
+        prob.setup()
 
         prob.run_model()
 
@@ -241,20 +238,20 @@ class TestBryoden(unittest.TestCase):
     def test_mixed(self):
         # Testing Broyden on a 5 state case split among 3 vars.
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', IndepVarComp('c', 0.01))
+        model.add_subsystem('p1', om.IndepVarComp('c', 0.01))
         model.add_subsystem('mixed', MixedEquation())
 
         model.connect('p1.c', 'mixed.c')
 
-        model.nonlinear_solver = BroydenSolver()
+        model.nonlinear_solver = om.BroydenSolver()
         model.nonlinear_solver.options['state_vars'] = ['mixed.x12', 'mixed.x3', 'mixed.x45']
         model.nonlinear_solver.options['maxiter'] = 15
         model.nonlinear_solver.options['compute_jacobian'] = False
 
-        prob.setup(check=False)
+        prob.setup()
 
         prob.run_model()
 
@@ -265,20 +262,20 @@ class TestBryoden(unittest.TestCase):
     def test_missing_state_warning(self):
         # Testing Broyden on a 5 state case split among 3 vars.
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', IndepVarComp('c', 0.01))
+        model.add_subsystem('p1', om.IndepVarComp('c', 0.01))
         model.add_subsystem('mixed', MixedEquation())
 
         model.connect('p1.c', 'mixed.c')
 
-        model.nonlinear_solver = BroydenSolver()
+        model.nonlinear_solver = om.BroydenSolver()
         model.nonlinear_solver.options['state_vars'] = ['mixed.x12']
         model.nonlinear_solver.options['maxiter'] = 15
         model.nonlinear_solver.options['compute_jacobian'] = False
 
-        prob.setup(check=False)
+        prob.setup()
 
         msg = "The following states are not covered by a solver, and may have been " \
               "omitted from the BroydenSolver 'state_vars': mixed.x3, mixed.x45"
@@ -287,20 +284,20 @@ class TestBryoden(unittest.TestCase):
             prob.run_model()
 
         # Try again with promoted names.
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', IndepVarComp('c', 0.01))
+        model.add_subsystem('p1', om.IndepVarComp('c', 0.01))
         model.add_subsystem('mixed', MixedEquation(), promotes=['*'])
 
         model.connect('p1.c', 'c')
 
-        model.nonlinear_solver = BroydenSolver()
+        model.nonlinear_solver = om.BroydenSolver()
         model.nonlinear_solver.options['state_vars'] = ['x12']
         model.nonlinear_solver.options['maxiter'] = 15
         model.nonlinear_solver.options['compute_jacobian'] = False
 
-        prob.setup(check=False)
+        prob.setup()
 
         msg = "The following states are not covered by a solver, and may have been " \
               "omitted from the BroydenSolver 'state_vars': x3, x45"
@@ -311,20 +308,20 @@ class TestBryoden(unittest.TestCase):
     def test_mixed_promoted_vars(self):
         # Testing Broyden on a 5 state case split among 3 vars.
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', IndepVarComp('c', 0.01))
+        model.add_subsystem('p1', om.IndepVarComp('c', 0.01))
         model.add_subsystem('mixed', MixedEquation(), promotes_outputs=['x12', 'x3', 'x45'])
 
         model.connect('p1.c', 'mixed.c')
 
-        model.nonlinear_solver = BroydenSolver()
+        model.nonlinear_solver = om.BroydenSolver()
         model.nonlinear_solver.options['state_vars'] = ['x12', 'x3', 'x45']
         model.nonlinear_solver.options['maxiter'] = 15
         model.nonlinear_solver.options['compute_jacobian'] = False
 
-        prob.setup(check=False)
+        prob.setup()
 
         prob.run_model()
 
@@ -335,20 +332,20 @@ class TestBryoden(unittest.TestCase):
     def test_mixed_jacobian(self):
         # Testing Broyden on a 5 state case split among 3 vars.
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', IndepVarComp('c', 0.01))
+        model.add_subsystem('p1', om.IndepVarComp('c', 0.01))
         model.add_subsystem('mixed', MixedEquation())
 
         model.connect('p1.c', 'mixed.c')
 
-        model.nonlinear_solver = BroydenSolver()
+        model.nonlinear_solver = om.BroydenSolver()
         model.nonlinear_solver.options['state_vars'] = ['mixed.x12', 'mixed.x3', 'mixed.x45']
         model.nonlinear_solver.options['maxiter'] = 15
-        model.nonlinear_solver.linear_solver = DirectSolver()
+        model.nonlinear_solver.linear_solver = om.DirectSolver()
 
-        prob.setup(check=False)
+        prob.setup()
 
         prob.run_model()
 
@@ -363,14 +360,14 @@ class TestBryoden(unittest.TestCase):
     def test_simple_sellar_jacobian(self):
         # Test top level Sellar (i.e., not grouped).
 
-        prob = Problem()
-        model = prob.model = SellarStateConnection(nonlinear_solver=BroydenSolver(),
-                                                   linear_solver=LinearRunOnce())
+        prob = om.Problem()
+        model = prob.model = SellarStateConnection(nonlinear_solver=om.BroydenSolver(),
+                                                   linear_solver=om.LinearRunOnce())
 
-        prob.setup(check=False)
+        prob.setup()
 
         model.nonlinear_solver.options['state_vars'] = ['state_eq.y2_command']
-        model.nonlinear_solver.linear_solver = DirectSolver(assemble_jac=False)
+        model.nonlinear_solver.linear_solver = om.DirectSolver(assemble_jac=False)
 
         prob.run_model()
 
@@ -384,13 +381,13 @@ class TestBryoden(unittest.TestCase):
     def test_simple_sellar_jacobian_assembled(self):
         # Test top level Sellar (i.e., not grouped).
 
-        prob = Problem()
-        model = prob.model = SellarStateConnection(nonlinear_solver=BroydenSolver(),
-                                                   linear_solver=LinearRunOnce())
+        prob = om.Problem()
+        model = prob.model = SellarStateConnection(nonlinear_solver=om.BroydenSolver(),
+                                                   linear_solver=om.LinearRunOnce())
 
-        prob.setup(check=False)
+        prob.setup()
 
-        model.nonlinear_solver.linear_solver = DirectSolver(assemble_jac=True)
+        model.nonlinear_solver.linear_solver = om.DirectSolver(assemble_jac=True)
 
         prob.run_model()
 
@@ -404,14 +401,14 @@ class TestBryoden(unittest.TestCase):
     def test_simple_sellar_jacobian_assembled_dense(self):
         # Test top level Sellar (i.e., not grouped).
 
-        prob = Problem()
-        model = prob.model = SellarStateConnection(nonlinear_solver=BroydenSolver(),
-                                                   linear_solver=LinearRunOnce())
+        prob = om.Problem()
+        model = prob.model = SellarStateConnection(nonlinear_solver=om.BroydenSolver(),
+                                                   linear_solver=om.LinearRunOnce())
 
-        prob.setup(check=False)
+        prob.setup()
 
         model.options['assembled_jac_type'] = 'dense'
-        model.nonlinear_solver.linear_solver = DirectSolver(assemble_jac=True)
+        model.nonlinear_solver.linear_solver = om.DirectSolver(assemble_jac=True)
 
         prob.run_model()
 
@@ -425,13 +422,13 @@ class TestBryoden(unittest.TestCase):
     def test_simple_sellar_full(self):
         # Test top level Sellar (i.e., not grouped).
 
-        prob = Problem()
-        model = prob.model = SellarStateConnection(nonlinear_solver=BroydenSolver(),
-                                                   linear_solver=LinearRunOnce())
+        prob = om.Problem()
+        model = prob.model = SellarStateConnection(nonlinear_solver=om.BroydenSolver(),
+                                                   linear_solver=om.LinearRunOnce())
 
-        prob.setup(check=False)
+        prob.setup()
 
-        model.nonlinear_solver.linear_solver = DirectSolver()
+        model.nonlinear_solver.linear_solver = om.DirectSolver()
         model.nonlinear_solver.options['compute_jacobian'] = False
 
         prob.run_model()
@@ -446,13 +443,13 @@ class TestBryoden(unittest.TestCase):
     def test_simple_sellar_full_jacobian(self):
         # Test top level Sellar (i.e., not grouped).
 
-        prob = Problem()
-        model = prob.model = SellarStateConnection(nonlinear_solver=BroydenSolver(),
-                                                   linear_solver=LinearRunOnce())
+        prob = om.Problem()
+        model = prob.model = SellarStateConnection(nonlinear_solver=om.BroydenSolver(),
+                                                   linear_solver=om.LinearRunOnce())
 
-        prob.setup(check=False)
+        prob.setup()
 
-        model.nonlinear_solver.linear_solver = DirectSolver()
+        model.nonlinear_solver.linear_solver = om.DirectSolver()
 
         prob.run_model()
 
@@ -466,22 +463,22 @@ class TestBryoden(unittest.TestCase):
     def test_jacobian_update_converge_limit(self):
         # This model needs jacobian updates to converge.
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', IndepVarComp('x', np.array([0, 20.0])))
+        model.add_subsystem('p1', om.IndepVarComp('x', np.array([0, 20.0])))
         model.add_subsystem('comp', SpedicatoHuang())
 
         model.connect('p1.x', 'comp.x')
 
-        model.nonlinear_solver = BroydenSolver()
+        model.nonlinear_solver = om.BroydenSolver()
         model.nonlinear_solver.options['state_vars'] = ['comp.y']
         model.nonlinear_solver.options['maxiter'] = 20
         model.nonlinear_solver.options['max_converge_failures'] = 1
         model.nonlinear_solver.options['diverge_limit'] = np.inf
-        model.nonlinear_solver.linear_solver = DirectSolver()
+        model.nonlinear_solver.linear_solver = om.DirectSolver()
 
-        prob.setup(check=False)
+        prob.setup()
 
         prob.set_solver_print(level=2)
         prob.run_model()
@@ -491,21 +488,21 @@ class TestBryoden(unittest.TestCase):
     def test_jacobian_update_diverge_limit(self):
         # This model needs jacobian updates to converge.
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('p1', IndepVarComp('x', np.array([0, 20.0])))
+        model.add_subsystem('p1', om.IndepVarComp('x', np.array([0, 20.0])))
         model.add_subsystem('comp', SpedicatoHuang())
 
         model.connect('p1.x', 'comp.x')
 
-        model.nonlinear_solver = BroydenSolver()
+        model.nonlinear_solver = om.BroydenSolver()
         model.nonlinear_solver.options['state_vars'] = ['comp.y']
         model.nonlinear_solver.options['maxiter'] = 20
         model.nonlinear_solver.options['diverge_limit'] = 0.5
-        model.nonlinear_solver.linear_solver = DirectSolver()
+        model.nonlinear_solver.linear_solver = om.DirectSolver()
 
-        prob.setup(check=False)
+        prob.setup()
 
         prob.set_solver_print(level=2)
         prob.run_model()
@@ -513,23 +510,23 @@ class TestBryoden(unittest.TestCase):
         assert_rel_error(self, prob['comp.y'], np.array([-36.26230985,  10.20857237, -54.17658612]), 1e-6)
 
     def test_backtracking(self):
-        top = Problem()
-        top.model.add_subsystem('px', IndepVarComp('x', 1.0))
+        top = om.Problem()
+        top.model.add_subsystem('px', om.IndepVarComp('x', 1.0))
         top.model.add_subsystem('comp', ImplCompTwoStates())
         top.model.connect('px.x', 'comp.x')
 
-        top.model.nonlinear_solver = BroydenSolver()
+        top.model.nonlinear_solver = om.BroydenSolver()
         top.model.nonlinear_solver.options['maxiter'] = 25
         top.model.nonlinear_solver.options['diverge_limit'] = 0.5
         top.model.nonlinear_solver.options['state_vars'] = ['comp.y', 'comp.z']
 
-        top.model.linear_solver = DirectSolver()
+        top.model.linear_solver = om.DirectSolver()
 
-        top.setup(check=False)
-        top.model.nonlinear_solver.linesearch = BoundsEnforceLS(bound_enforcement='vector')
+        top.setup()
+        top.model.nonlinear_solver.linesearch = om.BoundsEnforceLS(bound_enforcement='vector')
 
         # Setup again because we assigned a new linesearch
-        top.setup(check=False)
+        top.setup()
 
         top.set_solver_print(level=2)
         # Test lower bound: should go to the lower bound and stall
@@ -549,26 +546,28 @@ class TestBryoden(unittest.TestCase):
     def test_cs_around_broyden(self):
         # Basic sellar test.
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
-        sub = model.add_subsystem('sub', Group(), promotes=['*'])
+        sub = model.add_subsystem('sub', om.Group(), promotes=['*'])
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         sub.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         sub.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
                                                 z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'),
+                            promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'),
+                            promotes=['con2', 'y2'])
 
-        sub.nonlinear_solver = BroydenSolver()
-        sub.linear_solver = DirectSolver()
-        model.linear_solver = DirectSolver()
+        sub.nonlinear_solver = om.BroydenSolver()
+        sub.linear_solver = om.DirectSolver()
+        model.linear_solver = om.DirectSolver()
 
         prob.model.add_design_var('x', lower=-100, upper=100)
         prob.model.add_design_var('z', lower=-100, upper=100)
@@ -589,26 +588,26 @@ class TestBryoden(unittest.TestCase):
     def test_cs_around_broyden_compute_jac(self):
         # Basic sellar test.
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
-        sub = model.add_subsystem('sub', Group(), promotes=['*'])
+        sub = model.add_subsystem('sub', om.Group(), promotes=['*'])
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         sub.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         sub.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
                                                 z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        sub.nonlinear_solver = BroydenSolver()
-        sub.linear_solver = DirectSolver(assemble_jac=False)
-        model.linear_solver = DirectSolver(assemble_jac=False)
+        sub.nonlinear_solver = om.BroydenSolver()
+        sub.linear_solver = om.DirectSolver(assemble_jac=False)
+        model.linear_solver = om.DirectSolver(assemble_jac=False)
 
         prob.model.add_design_var('x', lower=-100, upper=100)
         prob.model.add_design_var('z', lower=-100, upper=100)
@@ -631,26 +630,26 @@ class TestBryoden(unittest.TestCase):
     def test_cs_around_broyden_compute_jac_dense(self):
         # Basic sellar test.
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
-        sub = model.add_subsystem('sub', Group(), promotes=['*'])
+        sub = model.add_subsystem('sub', om.Group(), promotes=['*'])
 
-        model.add_subsystem('px', IndepVarComp('x', 1.0), promotes=['x'])
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
+        model.add_subsystem('px', om.IndepVarComp('x', 1.0), promotes=['x'])
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])), promotes=['z'])
 
         sub.add_subsystem('d1', SellarDis1withDerivatives(), promotes=['x', 'z', 'y1', 'y2'])
         sub.add_subsystem('d2', SellarDis2withDerivatives(), promotes=['z', 'y1', 'y2'])
 
-        model.add_subsystem('obj_cmp', ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
+        model.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
                                                 z=np.array([0.0, 0.0]), x=0.0),
                             promotes=['obj', 'x', 'z', 'y1', 'y2'])
 
-        model.add_subsystem('con_cmp1', ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
-        model.add_subsystem('con_cmp2', ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
+        model.add_subsystem('con_cmp1', om.ExecComp('con1 = 3.16 - y1'), promotes=['con1', 'y1'])
+        model.add_subsystem('con_cmp2', om.ExecComp('con2 = y2 - 24.0'), promotes=['con2', 'y2'])
 
-        sub.nonlinear_solver = BroydenSolver()
-        sub.linear_solver = DirectSolver()
-        model.linear_solver = DirectSolver()
+        sub.nonlinear_solver = om.BroydenSolver()
+        sub.linear_solver = om.DirectSolver()
+        model.linear_solver = om.DirectSolver()
 
         prob.model.add_design_var('x', lower=-100, upper=100)
         prob.model.add_design_var('z', lower=-100, upper=100)
@@ -674,12 +673,12 @@ class TestBryoden(unittest.TestCase):
 class TestBryodenFeature(unittest.TestCase):
 
     def test_sellar(self):
-        from openmdao.api import Problem, LinearRunOnce, IndepVarComp, BroydenSolver
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarStateConnection
 
-        prob = Problem()
-        model = prob.model = SellarStateConnection(nonlinear_solver=BroydenSolver(),
-                                                   linear_solver=LinearRunOnce())
+        prob = om.Problem()
+        model = prob.model = SellarStateConnection(nonlinear_solver=om.BroydenSolver(),
+                                                   linear_solver=om.LinearRunOnce())
 
         prob.setup()
 
@@ -693,15 +692,14 @@ class TestBryodenFeature(unittest.TestCase):
         assert_rel_error(self, prob['state_eq.y2_command'], 12.05848819, .00001)
 
     def test_circuit(self):
-        from openmdao.api import Group, BroydenSolver, DirectSolver, Problem, IndepVarComp, LinearBlockGS
-
+        import openmdao.api as om
         from openmdao.test_suite.scripts.circuit_analysis import Circuit
 
-        p = Problem()
+        p = om.Problem()
         model = p.model
 
-        model.add_subsystem('ground', IndepVarComp('V', 0., units='V'))
-        model.add_subsystem('source', IndepVarComp('I', 0.1, units='A'))
+        model.add_subsystem('ground', om.IndepVarComp('V', 0., units='V'))
+        model.add_subsystem('source', om.IndepVarComp('I', 0.1, units='A'))
         model.add_subsystem('circuit', Circuit())
 
         model.connect('source.I', 'circuit.I_in')
@@ -709,14 +707,14 @@ class TestBryodenFeature(unittest.TestCase):
 
         p.setup()
 
-        # Replace existing solver with BroydenSolver
-        model.circuit.nonlinear_solver = BroydenSolver()
+        # Replace existing solver with om.BroydenSolver
+        model.circuit.nonlinear_solver = om.BroydenSolver()
         model.circuit.nonlinear_solver.options['maxiter'] = 20
 
         # Specify states for Broyden to solve
         model.circuit.nonlinear_solver.options['state_vars'] = ['n1.V', 'n2.V']
 
-        model.nonlinear_solver.linear_solver = LinearBlockGS()
+        model.nonlinear_solver.linear_solver = om.LinearBlockGS()
 
         # set some initial guesses
         p['circuit.n1.V'] = 10.
@@ -725,22 +723,21 @@ class TestBryodenFeature(unittest.TestCase):
         p.set_solver_print(level=2)
         p.run_model()
 
-        assert_rel_error(self, p['circuit.n1.V'], 9.90830282, 1e-5)
-        assert_rel_error(self, p['circuit.n2.V'], 0.73858486, 1e-5)
+        assert_rel_error(self, p['circuit.n1.V'], 9.90804735, 1e-5)
+        assert_rel_error(self, p['circuit.n2.V'], 0.71278226, 1e-5)
 
         # sanity check: should sum to .1 Amps
         assert_rel_error(self,  p['circuit.R1.I'] + p['circuit.D1.I'], .1, 1e-6)
 
     def test_circuit_options(self):
-        from openmdao.api import Group, BroydenSolver, DirectSolver, Problem, IndepVarComp
-
+        import openmdao.api as om
         from openmdao.test_suite.scripts.circuit_analysis import Circuit
 
-        p = Problem()
+        p = om.Problem()
         model = p.model
 
-        model.add_subsystem('ground', IndepVarComp('V', 0., units='V'))
-        model.add_subsystem('source', IndepVarComp('I', 0.1, units='A'))
+        model.add_subsystem('ground', om.IndepVarComp('V', 0., units='V'))
+        model.add_subsystem('source', om.IndepVarComp('I', 0.1, units='A'))
         model.add_subsystem('circuit', Circuit())
 
         model.connect('source.I', 'circuit.I_in')
@@ -749,7 +746,7 @@ class TestBryodenFeature(unittest.TestCase):
         p.setup()
 
         # Replace existing solver with BroydenSolver
-        model.circuit.nonlinear_solver = BroydenSolver()
+        model.circuit.nonlinear_solver = om.BroydenSolver()
         model.circuit.nonlinear_solver.options['maxiter'] = 20
         model.circuit.nonlinear_solver.options['converge_limit'] = 0.1
         model.circuit.nonlinear_solver.options['max_converge_failures'] = 1
@@ -764,22 +761,21 @@ class TestBryodenFeature(unittest.TestCase):
         p.set_solver_print(level=2)
         p.run_model()
 
-        assert_rel_error(self, p['circuit.n1.V'], 9.90830282, 1e-5)
-        assert_rel_error(self, p['circuit.n2.V'], 0.73858486, 1e-5)
+        assert_rel_error(self, p['circuit.n1.V'], 9.90804735, 1e-5)
+        assert_rel_error(self, p['circuit.n2.V'], 0.71278226, 1e-5)
 
         # sanity check: should sum to .1 Amps
         assert_rel_error(self,  p['circuit.R1.I'] + p['circuit.D1.I'], .1, 1e-6)
 
     def test_circuit_full(self):
-        from openmdao.api import Group, BroydenSolver, DirectSolver, Problem, IndepVarComp
-
+        import openmdao.api as om
         from openmdao.test_suite.scripts.circuit_analysis import Circuit
 
-        p = Problem()
+        p = om.Problem()
         model = p.model
 
-        model.add_subsystem('ground', IndepVarComp('V', 0., units='V'))
-        model.add_subsystem('source', IndepVarComp('I', 0.1, units='A'))
+        model.add_subsystem('ground', om.IndepVarComp('V', 0., units='V'))
+        model.add_subsystem('source', om.IndepVarComp('I', 0.1, units='A'))
         model.add_subsystem('circuit', Circuit())
 
         model.connect('source.I', 'circuit.I_in')
@@ -788,9 +784,9 @@ class TestBryodenFeature(unittest.TestCase):
         p.setup()
 
         # Replace existing solver with BroydenSolver
-        model.circuit.nonlinear_solver = BroydenSolver()
+        model.circuit.nonlinear_solver = om.BroydenSolver()
         model.circuit.nonlinear_solver.options['maxiter'] = 20
-        model.circuit.nonlinear_solver.linear_solver = DirectSolver()
+        model.circuit.nonlinear_solver.linear_solver = om.DirectSolver()
 
         # set some initial guesses
         p['circuit.n1.V'] = 10.
@@ -799,11 +795,12 @@ class TestBryodenFeature(unittest.TestCase):
         p.set_solver_print(level=2)
         p.run_model()
 
-        assert_rel_error(self, p['circuit.n1.V'], 9.90830282, 1e-5)
-        assert_rel_error(self, p['circuit.n2.V'], 0.73858486, 1e-5)
+        assert_rel_error(self, p['circuit.n1.V'], 9.90804735, 1e-5)
+        assert_rel_error(self, p['circuit.n2.V'], 0.71278226, 1e-5)
 
         # sanity check: should sum to .1 Amps
         assert_rel_error(self,  p['circuit.R1.I'] + p['circuit.D1.I'], .1, 1e-6)
 
+
 if __name__ == "__main__":
-    unittest.main()
\ No newline at end of file
+    unittest.main()
