@@ -6,8 +6,7 @@ import unittest
 
 import numpy as np
 
-from openmdao.api import Problem, NewtonSolver, ScipyKrylov, Group, PETScVector, \
-    IndepVarComp, NonlinearBlockGS, NonlinearBlockJac, LinearBlockGS
+import openmdao.api as om
 from openmdao.test_suite.components.double_sellar import SubSellar
 from openmdao.test_suite.components.sellar import SellarDerivatives
 
@@ -18,16 +17,16 @@ from openmdao.utils.mpi import MPI
 class TestSolverPrint(unittest.TestCase):
 
     def test_feature_iprint_neg1(self):
-        from openmdao.api import Problem, NewtonSolver, ScipyKrylov
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDerivatives
 
-        prob = Problem()
+        prob = om.Problem()
         prob.model = SellarDerivatives()
 
         prob.setup()
 
-        newton = prob.model.nonlinear_solver = NewtonSolver()
-        scipy = prob.model.linear_solver = ScipyKrylov()
+        newton = prob.model.nonlinear_solver = om.NewtonSolver()
+        scipy = prob.model.linear_solver = om.ScipyKrylov()
 
         newton.options['maxiter'] = 2
 
@@ -40,16 +39,16 @@ class TestSolverPrint(unittest.TestCase):
         prob.run_model()
 
     def test_feature_iprint_0(self):
-        from openmdao.api import Problem, NewtonSolver, ScipyKrylov
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDerivatives
 
-        prob = Problem()
+        prob = om.Problem()
         prob.model = SellarDerivatives()
 
         prob.setup()
 
-        newton = prob.model.nonlinear_solver = NewtonSolver()
-        scipy = prob.model.linear_solver = ScipyKrylov()
+        newton = prob.model.nonlinear_solver = om.NewtonSolver()
+        scipy = prob.model.linear_solver = om.ScipyKrylov()
 
         newton.options['maxiter'] = 1
 
@@ -62,16 +61,16 @@ class TestSolverPrint(unittest.TestCase):
         prob.run_model()
 
     def test_feature_iprint_1(self):
-        from openmdao.api import Problem, NewtonSolver, ScipyKrylov
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDerivatives
 
-        prob = Problem()
+        prob = om.Problem()
         prob.model = SellarDerivatives()
 
         prob.setup()
 
-        newton = prob.model.nonlinear_solver = NewtonSolver()
-        scipy = prob.model.linear_solver = ScipyKrylov()
+        newton = prob.model.nonlinear_solver = om.NewtonSolver()
+        scipy = prob.model.linear_solver = om.ScipyKrylov()
 
         newton.options['maxiter'] = 20
 
@@ -83,16 +82,16 @@ class TestSolverPrint(unittest.TestCase):
         prob.run_model()
 
     def test_feature_iprint_2(self):
-        from openmdao.api import Problem, NewtonSolver, ScipyKrylov
+        import openmdao.api as om
         from openmdao.test_suite.components.sellar import SellarDerivatives
 
-        prob = Problem()
+        prob = om.Problem()
         prob.model = SellarDerivatives()
 
         prob.setup()
 
-        newton = prob.model.nonlinear_solver = NewtonSolver()
-        scipy = prob.model.linear_solver = ScipyKrylov()
+        newton = prob.model.nonlinear_solver = om.NewtonSolver()
+        scipy = prob.model.linear_solver = om.ScipyKrylov()
 
         newton.options['maxiter'] = 20
 
@@ -105,13 +104,13 @@ class TestSolverPrint(unittest.TestCase):
 
     def test_hierarchy_iprint(self):
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])))
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])))
 
-        sub1 = model.add_subsystem('sub1', Group())
-        sub2 = sub1.add_subsystem('sub2', Group())
+        sub1 = model.add_subsystem('sub1', om.Group())
+        sub2 = sub1.add_subsystem('sub2', om.Group())
         g1 = sub2.add_subsystem('g1', SubSellar())
         g2 = model.add_subsystem('g2', SubSellar())
 
@@ -119,35 +118,35 @@ class TestSolverPrint(unittest.TestCase):
         model.connect('sub1.sub2.g1.y2', 'g2.x')
         model.connect('g2.y2', 'sub1.sub2.g1.x')
 
-        model.nonlinear_solver = NewtonSolver()
-        model.linear_solver = ScipyKrylov()
+        model.nonlinear_solver = om.NewtonSolver()
+        model.linear_solver = om.ScipyKrylov()
         model.nonlinear_solver.options['solve_subsystems'] = True
         model.nonlinear_solver.options['max_sub_solves'] = 0
 
-        g1.nonlinear_solver = NewtonSolver()
-        g1.linear_solver = LinearBlockGS()
+        g1.nonlinear_solver = om.NewtonSolver()
+        g1.linear_solver = om.LinearBlockGS()
 
-        g2.nonlinear_solver = NewtonSolver()
-        g2.linear_solver = ScipyKrylov()
-        g2.linear_solver.precon = LinearBlockGS()
+        g2.nonlinear_solver = om.NewtonSolver()
+        g2.linear_solver = om.ScipyKrylov()
+        g2.linear_solver.precon = om.LinearBlockGS()
         g2.linear_solver.precon.options['maxiter'] = 2
 
         prob.set_solver_print(level=2)
 
-        prob.setup(check=False)
+        prob.setup()
 
         output = run_model(prob)
         # TODO: check output
 
     def test_hierarchy_iprint2(self):
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])))
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])))
 
-        sub1 = model.add_subsystem('sub1', Group())
-        sub2 = sub1.add_subsystem('sub2', Group())
+        sub1 = model.add_subsystem('sub1', om.Group())
+        sub2 = sub1.add_subsystem('sub2', om.Group())
         g1 = sub2.add_subsystem('g1', SubSellar())
         g2 = model.add_subsystem('g2', SubSellar())
 
@@ -155,26 +154,26 @@ class TestSolverPrint(unittest.TestCase):
         model.connect('sub1.sub2.g1.y2', 'g2.x')
         model.connect('g2.y2', 'sub1.sub2.g1.x')
 
-        model.nonlinear_solver = NonlinearBlockGS()
-        g1.nonlinear_solver = NonlinearBlockGS()
-        g2.nonlinear_solver = NonlinearBlockGS()
+        model.nonlinear_solver = om.NonlinearBlockGS()
+        g1.nonlinear_solver = om.NonlinearBlockGS()
+        g2.nonlinear_solver = om.NonlinearBlockGS()
 
         prob.set_solver_print(level=2)
 
-        prob.setup(check=False)
+        prob.setup()
 
         output = run_model(prob)
         # TODO: check output
 
     def test_hierarchy_iprint3(self):
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])))
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])))
 
-        sub1 = model.add_subsystem('sub1', Group())
-        sub2 = sub1.add_subsystem('sub2', Group())
+        sub1 = model.add_subsystem('sub1', om.Group())
+        sub2 = sub1.add_subsystem('sub2', om.Group())
         g1 = sub2.add_subsystem('g1', SubSellar())
         g2 = model.add_subsystem('g2', SubSellar())
 
@@ -182,15 +181,15 @@ class TestSolverPrint(unittest.TestCase):
         model.connect('sub1.sub2.g1.y2', 'g2.x')
         model.connect('g2.y2', 'sub1.sub2.g1.x')
 
-        model.nonlinear_solver = NonlinearBlockJac()
-        sub1.nonlinear_solver = NonlinearBlockJac()
-        sub2.nonlinear_solver = NonlinearBlockJac()
-        g1.nonlinear_solver = NonlinearBlockJac()
-        g2.nonlinear_solver = NonlinearBlockJac()
+        model.nonlinear_solver = om.NonlinearBlockJac()
+        sub1.nonlinear_solver = om.NonlinearBlockJac()
+        sub2.nonlinear_solver = om.NonlinearBlockJac()
+        g1.nonlinear_solver = om.NonlinearBlockJac()
+        g2.nonlinear_solver = om.NonlinearBlockJac()
 
         prob.set_solver_print(level=2)
 
-        prob.setup(check=False)
+        prob.setup()
 
         output = run_model(prob)
         # TODO: check output
@@ -198,16 +197,16 @@ class TestSolverPrint(unittest.TestCase):
     def test_feature_set_solver_print1(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, NewtonSolver, ScipyKrylov, LinearBlockGS
+        import openmdao.api as om
         from openmdao.test_suite.components.double_sellar import SubSellar
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])))
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])))
 
-        sub1 = model.add_subsystem('sub1', Group())
-        sub2 = sub1.add_subsystem('sub2', Group())
+        sub1 = model.add_subsystem('sub1', om.Group())
+        sub2 = sub1.add_subsystem('sub2', om.Group())
         g1 = sub2.add_subsystem('g1', SubSellar())
         g2 = model.add_subsystem('g2', SubSellar())
 
@@ -215,17 +214,17 @@ class TestSolverPrint(unittest.TestCase):
         model.connect('sub1.sub2.g1.y2', 'g2.x')
         model.connect('g2.y2', 'sub1.sub2.g1.x')
 
-        model.nonlinear_solver = NewtonSolver()
-        model.linear_solver = ScipyKrylov()
+        model.nonlinear_solver = om.NewtonSolver()
+        model.linear_solver = om.ScipyKrylov()
         model.nonlinear_solver.options['solve_subsystems'] = True
         model.nonlinear_solver.options['max_sub_solves'] = 0
 
-        g1.nonlinear_solver = NewtonSolver()
-        g1.linear_solver = LinearBlockGS()
+        g1.nonlinear_solver = om.NewtonSolver()
+        g1.linear_solver = om.LinearBlockGS()
 
-        g2.nonlinear_solver = NewtonSolver()
-        g2.linear_solver = ScipyKrylov()
-        g2.linear_solver.precon = LinearBlockGS()
+        g2.nonlinear_solver = om.NewtonSolver()
+        g2.linear_solver = om.ScipyKrylov()
+        g2.linear_solver.precon = om.LinearBlockGS()
         g2.linear_solver.precon.options['maxiter'] = 2
 
         prob.set_solver_print(level=2)
@@ -236,16 +235,16 @@ class TestSolverPrint(unittest.TestCase):
     def test_feature_set_solver_print2(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, NewtonSolver, ScipyKrylov, LinearBlockGS
+        import openmdao.api as om
         from openmdao.test_suite.components.double_sellar import SubSellar
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])))
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])))
 
-        sub1 = model.add_subsystem('sub1', Group())
-        sub2 = sub1.add_subsystem('sub2', Group())
+        sub1 = model.add_subsystem('sub1', om.Group())
+        sub2 = sub1.add_subsystem('sub2', om.Group())
         g1 = sub2.add_subsystem('g1', SubSellar())
         g2 = model.add_subsystem('g2', SubSellar())
 
@@ -253,17 +252,17 @@ class TestSolverPrint(unittest.TestCase):
         model.connect('sub1.sub2.g1.y2', 'g2.x')
         model.connect('g2.y2', 'sub1.sub2.g1.x')
 
-        model.nonlinear_solver = NewtonSolver()
-        model.linear_solver = ScipyKrylov()
+        model.nonlinear_solver = om.NewtonSolver()
+        model.linear_solver = om.ScipyKrylov()
         model.nonlinear_solver.options['solve_subsystems'] = True
         model.nonlinear_solver.options['max_sub_solves'] = 0
 
-        g1.nonlinear_solver = NewtonSolver()
-        g1.linear_solver = LinearBlockGS()
+        g1.nonlinear_solver = om.NewtonSolver()
+        g1.linear_solver = om.LinearBlockGS()
 
-        g2.nonlinear_solver = NewtonSolver()
-        g2.linear_solver = ScipyKrylov()
-        g2.linear_solver.precon = LinearBlockGS()
+        g2.nonlinear_solver = om.NewtonSolver()
+        g2.linear_solver = om.ScipyKrylov()
+        g2.linear_solver.precon = om.LinearBlockGS()
         g2.linear_solver.precon.options['maxiter'] = 2
 
         prob.set_solver_print(level=2)
@@ -275,16 +274,16 @@ class TestSolverPrint(unittest.TestCase):
     def test_feature_set_solver_print3(self):
         import numpy as np
 
-        from openmdao.api import Problem, Group, IndepVarComp, NewtonSolver, ScipyKrylov, LinearBlockGS
+        import openmdao.api as om
         from openmdao.test_suite.components.double_sellar import SubSellar
 
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])))
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])))
 
-        sub1 = model.add_subsystem('sub1', Group())
-        sub2 = sub1.add_subsystem('sub2', Group())
+        sub1 = model.add_subsystem('sub1', om.Group())
+        sub2 = sub1.add_subsystem('sub2', om.Group())
         g1 = sub2.add_subsystem('g1', SubSellar())
         g2 = model.add_subsystem('g2', SubSellar())
 
@@ -292,17 +291,17 @@ class TestSolverPrint(unittest.TestCase):
         model.connect('sub1.sub2.g1.y2', 'g2.x')
         model.connect('g2.y2', 'sub1.sub2.g1.x')
 
-        model.nonlinear_solver = NewtonSolver()
-        model.linear_solver = ScipyKrylov()
+        model.nonlinear_solver = om.NewtonSolver()
+        model.linear_solver = om.ScipyKrylov()
         model.nonlinear_solver.options['solve_subsystems'] = True
         model.nonlinear_solver.options['max_sub_solves'] = 0
 
-        g1.nonlinear_solver = NewtonSolver()
-        g1.linear_solver = LinearBlockGS()
+        g1.nonlinear_solver = om.NewtonSolver()
+        g1.linear_solver = om.LinearBlockGS()
 
-        g2.nonlinear_solver = NewtonSolver()
-        g2.linear_solver = ScipyKrylov()
-        g2.linear_solver.precon = LinearBlockGS()
+        g2.nonlinear_solver = om.NewtonSolver()
+        g2.linear_solver = om.ScipyKrylov()
+        g2.linear_solver.precon = om.LinearBlockGS()
         g2.linear_solver.precon.options['maxiter'] = 2
 
         prob.set_solver_print(level=0)
@@ -312,20 +311,20 @@ class TestSolverPrint(unittest.TestCase):
         prob.run_model()
 
 
-@unittest.skipUnless(PETScVector, "PETSc is required.")
+@unittest.skipUnless(om.PETScVector, "PETSc is required.")
 class MPITests(unittest.TestCase):
 
     N_PROCS = 2
 
     @unittest.skipUnless(MPI, "MPI is not active.")
     def test_hierarchy_iprint(self):
-        prob = Problem()
+        prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('pz', IndepVarComp('z', np.array([5.0, 2.0])))
+        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])))
 
-        sub1 = model.add_subsystem('sub1', Group())
-        sub2 = sub1.add_subsystem('sub2', Group())
+        sub1 = model.add_subsystem('sub1', om.Group())
+        sub2 = sub1.add_subsystem('sub2', om.Group())
         g1 = sub2.add_subsystem('g1', SubSellar())
         g2 = model.add_subsystem('g2', SubSellar())
 
@@ -333,22 +332,22 @@ class MPITests(unittest.TestCase):
         model.connect('sub1.sub2.g1.y2', 'g2.x')
         model.connect('g2.y2', 'sub1.sub2.g1.x')
 
-        model.nonlinear_solver = NewtonSolver()
-        model.linear_solver = ScipyKrylov()
+        model.nonlinear_solver = om.NewtonSolver()
+        model.linear_solver = om.ScipyKrylov()
         model.nonlinear_solver.options['solve_subsystems'] = True
         model.nonlinear_solver.options['max_sub_solves'] = 0
 
-        g1.nonlinear_solver = NewtonSolver()
-        g1.linear_solver = LinearBlockGS()
+        g1.nonlinear_solver = om.NewtonSolver()
+        g1.linear_solver = om.LinearBlockGS()
 
-        g2.nonlinear_solver = NewtonSolver()
-        g2.linear_solver = ScipyKrylov()
-        g2.linear_solver.precon = LinearBlockGS()
+        g2.nonlinear_solver = om.NewtonSolver()
+        g2.linear_solver = om.ScipyKrylov()
+        g2.linear_solver.precon = om.LinearBlockGS()
         g2.linear_solver.precon.options['maxiter'] = 2
 
         prob.set_solver_print(level=2)
 
-        prob.setup(check=False)
+        prob.setup()
 
         # Conclude setup but don't run model.
         prob.final_setup()
